@@ -22,7 +22,7 @@
 Enhanced Version of the file for platform independent KDE tools.
 Copyright (c) 2004 Ulf Schenk
 
-$Id: address.cpp,v 1.3 2004/09/18 22:33:39 zautrix Exp $
+$Id: address.cpp,v 1.4 2005/08/22 15:42:41 zautrix Exp $
 */
 
 //US added kglobal.h
@@ -101,6 +101,33 @@ QStringList Address::asList()
     if ( ! mLabel.isEmpty() )result.append(mLabel);
     return result;
 }
+
+bool Address::matchAddress( QRegExp* re ) const
+{
+
+#if QT_VERSION >= 0x030000
+    if (re->search( mPostOfficeBox ) == 0) return true;
+    if (re->search( mExtended     ) == 0) return true;
+    if (re->search( mStreet     ) == 0) return true;
+    if (re->search( mLocality      ) == 0) return true;
+    if (re->search( mRegion      ) == 0) return true;
+    if (re->search( mPostalCode     ) == 0) return true;
+    if (re->search( mCountry     ) == 0) return true;
+    if (re->search( mLabel     ) == 0) return true;
+#else
+        if (re->match( mPostOfficeBox    ) == 0) return true;
+        if (re->match( mExtended     ) == 0) return true;
+        if (re->match( mStreet     ) == 0) return true;
+        if (re->match( mLocality     ) == 0) return true;
+        if (re->match( mRegion     ) == 0) return true;
+        if (re->match( mPostalCode     ) == 0) return true;
+        if (re->match( mCountry     ) == 0) return true;
+        if (re->match( mLabel    ) == 0) return true;
+#endif   
+
+    return false;
+}
+
 void Address::clear()
 {
   *this = Address();
