@@ -390,6 +390,7 @@ void AddresseeView::setAddressee( const KABC::Addressee& mAddressee )
   mText = "";
   QString picString = "";
   KABC::Picture picture = mAddressee.photo();
+  if (picture.undefined() ) picture = mAddressee.logo();
   bool picAvailintern = false;
   bool picAvailUrl = false;
   if (! picture.undefined() ) {
@@ -400,9 +401,34 @@ void AddresseeView::setAddressee( const KABC::Addressee& mAddressee )
       picString =  "<img src=\"myimage\" width=\"50\" height=\"70\">";
       if (  picAvailintern ) {
           QMimeSourceFactory::defaultFactory()->setImage( "myimage", picture.data() );
+          int wid = picture.data().width();
+          int hei = picture.data().height();  
+          if ( wid > 128 || hei > 128 ) {
+              if ( wid > hei ) {
+                  hei = (hei*128)/wid;
+                  wid = 128;
+              } else {
+                  wid = (wid*128)/hei;
+                  hei = 128;
+              }
+          }
+          picString =  QString("<img src=\"myimage\" width=\"%1\" height=\"%2\">").arg(wid).arg(hei);
       } else {
           if ( picAvailUrl ) {
-              QMimeSourceFactory::defaultFactory()->setPixmap( "myimage", QPixmap( picture.url() ));
+              QPixmap picPix( picture.url() );
+              QMimeSourceFactory::defaultFactory()->setPixmap( "myimage", picPix );
+              int wid = picPix.width();
+              int hei = picPix.height();
+              if ( wid > 128 || hei > 128 ) {
+                  if ( wid > hei ) {
+                      hei = (hei*128)/wid;
+                      wid = 128;
+                  } else {
+                      wid = (wid*128)/hei;
+                      hei = 128;
+                  }
+              }
+              picString =  QString("<img src=\"myimage\" width=\"%1\" height=\"%2\">").arg(wid).arg(hei);
           } else {
               if ( !mAddressee.custom( "KADDRESSBOOK", "X-Children" ).isEmpty() ) {
                   static bool setDefaultImageChildren = false;
