@@ -22,7 +22,7 @@
 Enhanced Version of the file for platform independent KDE tools.
 Copyright (c) 2004 Ulf Schenk
 
-$Id: stdaddressbook.cpp,v 1.10 2005/07/28 16:23:37 zautrix Exp $
+$Id: stdaddressbook.cpp,v 1.12 2005/08/23 14:22:11 zautrix Exp $
 */
 
 #include <qdir.h>
@@ -56,6 +56,23 @@ void StdAddressBook::handleCrash()
 {
   StdAddressBook::self()->cleanUp();
 }
+StdAddressBook *StdAddressBook::selfNoLoad()
+{
+
+  if ( !mSelf )
+  {
+      QString appdir = StdAddressBook::setTempAppDir();
+// US im am not sure why I have to use the other format here??
+#ifdef KAB_EMBEDDED
+      mSelf = addressBookDeleter.setObject( new StdAddressBook ( QString() ) );
+#else //KAB_EMBEDDED
+    addressBookDeleter.setObject( mSelf, new StdAddressBook( QString() ) );
+#endif //KAB_EMBEDDED
+    KStandardDirs::setAppDir( appdir );
+  }
+
+  return mSelf;
+}
 
 StdAddressBook *StdAddressBook::self()
 {
@@ -108,19 +125,24 @@ StdAddressBook *StdAddressBook::self( bool onlyFastResources )
   }
   return mSelf;
 }
+StdAddressBook::StdAddressBook( QString )
+  : AddressBook( "kabcrc" )
+{
+
+}
 
 StdAddressBook::StdAddressBook()
   : AddressBook( "kabcrc" )
 {
 
-  init( false );
+    init( false );
 }
 
 StdAddressBook::StdAddressBook( bool onlyFastResources )
   : AddressBook( "kabcrc" )
 {
 
-  init( onlyFastResources );
+    init( onlyFastResources );
 }
 
 StdAddressBook::~StdAddressBook()
