@@ -22,11 +22,12 @@
 Enhanced Version of the file for platform independent KDE tools.
 Copyright (c) 2004 Ulf Schenk
 
-$Id: vcardformatimpl.cpp,v 1.9 2005/01/06 00:18:16 zautrix Exp $
+$Id: vcardformatimpl.cpp,v 1.10 2005/07/06 09:29:34 zautrix Exp $
 */
 
 #include <qfile.h>
 #include <qregexp.h>
+#include <qapplication.h>
 
 #include <kdebug.h>
 #include <kmdcodec.h>
@@ -69,13 +70,12 @@ bool VCardFormatImpl::load( Addressee &addressee, QFile *file )
   return false;
 }
 
+
+#include <kmessagebox.h>
 bool VCardFormatImpl::loadAll( AddressBook *addressBook, Resource *resource, QFile *file )
 {
-  kdDebug(5700) << "VCardFormat::loadAll()" << endl;
-
-  QByteArray fdata = file->readAll();
-  QCString data(fdata.data(), fdata.size()+1);
-
+  
+    QCString data(file->readAll().data(), file->size()+1); 
   VCardEntity e( data );
 
   VCardListIterator it( e.cardList() );
@@ -92,7 +92,6 @@ bool VCardFormatImpl::loadAll( AddressBook *addressBook, Resource *resource, QFi
 	printf("address %s loaded successfully\n", addressee.formattedName().latin1());
       } 
   }
-
   return true;
 }
 
@@ -115,24 +114,17 @@ void VCardFormatImpl::save( const Addressee &addressee, QFile *file )
 
 void VCardFormatImpl::saveAll( AddressBook *ab, Resource *resource, QFile *file )
 {
-  VCardEntity vcards;
-  VCardList vcardlist;
-  vcardlist.setAutoDelete( true );
 
-  AddressBook::Iterator it;
+ AddressBook::Iterator it;
   for ( it = ab->begin(); it != ab->end(); ++it ) {
     if ( (*it).resource() == resource ) {
-      VCard *v = new VCard;
-      saveAddressee( (*it), v, true );
+        save((*it),file);
+        qApp->processEvents();
       (*it).setChanged( false );
-      vcardlist.append( v );
     }
   }
-
-  vcards.setCardList( vcardlist );
-
-  QCString vcardData = vcards.asString();
-  file->writeBlock( (const char*)vcardData, vcardData.length() );
+  // for memory usage status test only
+  // KMessageBox::information ( 0, "Stoppppp", QString("Stop ") );
 }
 
 bool VCardFormatImpl::loadAddressee( Addressee& addressee, VCard *v )
