@@ -188,21 +188,25 @@ void AddresseeEditorWidget::setupTab1()
   layout->addWidget( mNameEdit, 0, 1 );
   layout->addWidget( mNameLabel, 0, 1 );
   
-  label = new QLabel( i18n( "Role:" ), tab1 );
+  button = new QPushButton( i18n( "Role:" ), tab1 );
+  connect( button, SIGNAL( clicked() ), SLOT( setRole2FN() ) );
+  //label = new QLabel( i18n( "Role:" ), tab1 );
   mRoleEdit = new KLineEdit( tab1 );
   connect( mRoleEdit, SIGNAL( textChanged( const QString& ) ),
            SLOT( textChanged( const QString& ) ) );
-  label->setBuddy( mRoleEdit );
-  layout->addWidget( label, 1, 0 );
+  //label->setBuddy( mRoleEdit );
+  layout->addWidget( button, 1, 0 );
   layout->addWidget( mRoleEdit, 1, 1 );
   
   // Organization
-  label = new QLabel( i18n( "Organization:" ), tab1 );
+  button = new QPushButton( i18n( "Organization:" ), tab1 );
+  connect( button, SIGNAL( clicked() ), SLOT( setCompany2FN() ) );
+  //label = new QLabel( i18n( "Organization:" ), tab1 );
   mOrgEdit = new KLineEdit( tab1 );
-  label->setBuddy( mOrgEdit );
+  //label->setBuddy( mOrgEdit );
   connect( mOrgEdit, SIGNAL( textChanged( const QString& ) ), 
            SLOT( textChanged( const QString& ) ) );
-  layout->addWidget( label, 2, 0 );
+  layout->addWidget( button, 2, 0 );
   layout->addWidget( mOrgEdit, 2, 1 );
   
   // File as (formatted name)
@@ -325,6 +329,22 @@ void AddresseeEditorWidget::setupTab1()
   mTabWidget->addTab( tab1, i18n( "&General" ) );
 }
 
+void AddresseeEditorWidget::setRole2FN()
+{
+    if ( mRoleEdit->text().isEmpty() ) return;
+    mFormattedNameType = NameEditDialog::CustomName;
+    mAddressee.setFormattedName( mRoleEdit->text() ); 
+    mFormattedNameLabel->setText( mRoleEdit->text() );
+    mDirty = true;
+}
+void AddresseeEditorWidget::setCompany2FN()
+{
+    if (  mOrgEdit->text().isEmpty() ) return;
+    mFormattedNameType = NameEditDialog::CustomName;
+    mAddressee.setFormattedName( mOrgEdit->text() );
+    mFormattedNameLabel->setText( mOrgEdit->text() );
+    mDirty = true;
+}
 
 void AddresseeEditorWidget::setupTab1_1()
 {
