@@ -354,6 +354,7 @@ class KABCore : public QWidget, public KSyncInterface
     void contactSelected( const QString &name );
     void contactSelected( const QPixmap &pixmap );
   public slots:
+    void loadDataAfterStart();
     void recieve(QString cmsg );
     void getFile( bool success );
     void syncFileRequest();
@@ -366,6 +367,7 @@ class KABCore : public QWidget, public KSyncInterface
     void updateToolBar();
     void updateMainWindow();
     void receive( const QCString& cmsg, const QByteArray& data );
+    void receiveStart( const QCString& cmsg, const QByteArray& data );
     void toggleBeamReceive( );
     void disableBR(bool);
     void setJumpButtonBarVisible( bool visible );
@@ -392,6 +394,8 @@ class KABCore : public QWidget, public KSyncInterface
     void addressBookChanged();
 
   private:
+    QCString mCStringMess;
+    QByteArray mByteData;
     QString mEmailSourceChannel;
     QString mEmailSourceUID;
     void resizeEvent(QResizeEvent* e );
