@@ -142,6 +142,9 @@ KABConfigWidget::KABConfigWidget( KABPrefs* prefs, QWidget *parent, const char *
   mMultipleViewsAtOnce = new QCheckBox( i18n( "Display List and Details at once (restart)" ), vBox, "mdisplay" );
   boxLayout->addWidget( mMultipleViewsAtOnce );
 
+  mAskForDelete = new QCheckBox( i18n( "Ask before delete contact" ), vBox, "mdel" );
+  boxLayout->addWidget( mAskForDelete );
+
   mAskForQuit = new QCheckBox( i18n( "Show exit confirmation" ), vBox, "mquit" );
   boxLayout->addWidget( mAskForQuit );
 
@@ -185,6 +188,7 @@ KABConfigWidget::KABConfigWidget( KABPrefs* prefs, QWidget *parent, const char *
   connect( mHideSearchOnSwitchBox, SIGNAL( toggled( bool ) ), this, SLOT( modified() ) );
   connect( mMultipleViewsAtOnce, SIGNAL( toggled( bool ) ), this, SLOT( modified() ) );
   connect( mAskForQuit, SIGNAL( toggled( bool ) ), this, SLOT( modified() ) );
+  connect( mAskForDelete, SIGNAL( toggled( bool ) ), this, SLOT( modified() ) );
   connect( mExtensionView, SIGNAL( selectionChanged( QListViewItem* ) ),
            SLOT( selectionChanged( QListViewItem* ) ) );
   connect( mExtensionView, SIGNAL( clicked( QListViewItem* ) ),
@@ -215,6 +219,7 @@ void KABConfigWidget::usrReadConfig()
   mHideSearchOnSwitchBox->setChecked( prefs->mHideSearchOnSwitch );
   mMultipleViewsAtOnce->setChecked( prefs->mMultipleViewsAtOnce );
   mAskForQuit->setChecked( prefs->mAskForQuit );
+  mAskForDelete->setChecked( prefs->mAskForDelete );
 
   mAddresseeWidget->restoreSettings();
 
@@ -236,6 +241,7 @@ void KABConfigWidget::usrWriteConfig()
 
   prefs->mMultipleViewsAtOnce = mMultipleViewsAtOnce->isChecked();
   prefs->mAskForQuit = mAskForQuit->isChecked();
+  prefs->mAskForDelete = mAskForDelete->isChecked();
 
   mAddresseeWidget->saveSettings();
 
