@@ -25,7 +25,7 @@
 Enhanced Version of the file for platform independent KDE tools.
 Copyright (c) 2004 Ulf Schenk
 
-$Id: viewmanager.cpp,v 1.18 2005/04/22 18:54:02 zautrix Exp $
+$Id: viewmanager.cpp,v 1.19 2005/08/17 17:09:57 zautrix Exp $
 */
 
 
@@ -241,6 +241,9 @@ void ViewManager::setActiveView( const QString &name )
       view = factory->view( mCore->addressBook(), mViewWidgetStack );
 
     if ( view ) {
+        if ( !mViewNameList.contains( name ) ) {
+            mViewNameList.append( name );
+        }
       view->setCaption( name );
       mViewDict.insert( name, view );
 //US my version needs an int as second parameter to addWidget
@@ -290,6 +293,10 @@ void ViewManager::setActiveView( const QString &name )
 
 //US performance optimization. setActiveFilter calls also mActiveView->refresh()
 //US mActiveView->refresh();
+
+    mActionSelectView->setItems( mViewNameList );
+    mActionSelectView->setCurrentItem( mViewNameList.findIndex( mActiveView->caption() ) );
+
   }
   else
   {
