@@ -329,6 +329,7 @@ void KAddressBookCardView::doSearch( const QString&  s,KABC::Field *field  )
         for (it = addresseeList.begin(); it != addresseeList.end(); ++it ) {
             if ( (*it).uid().left(2) == "la" && (*it).uid().left(19) == QString("last-syncAddressee-") )
                 continue;
+            bool match = false;
             for ( fieldIt = fieldList.begin(); fieldIt != fieldList.end(); ++fieldIt ) {
 #if QT_VERSION >= 0x030000
                 if (re.search((*fieldIt)->value( *it ).lower()) == 0)
@@ -336,11 +337,28 @@ void KAddressBookCardView::doSearch( const QString&  s,KABC::Field *field  )
                     if (re.match((*fieldIt)->value( *it ).lower()) == 0)
 #endif   
                         { 
-                           new AddresseeCardViewItem(fields(), mShowEmptyFields,
-                                              addressBook(), *it, mCardView);
+                            new AddresseeCardViewItem(fields(), mShowEmptyFields,
+                                                      addressBook(), *it, mCardView);
+                            match = true;
                             break;
                         }
             }
+            if ( ! match ) {
+                if ( (*it).matchPhoneNumber( &re ) ) { 
+                    new AddresseeCardViewItem(fields(), mShowEmptyFields,
+                                              addressBook(), *it, mCardView);
+                    match = true;
+                    break;
+                }
+            }
+            if ( ! match ) {
+                if ( (*it).matchAddress( &re ) ) { 
+                    new AddresseeCardViewItem(fields(), mShowEmptyFields,
+                                              addressBook(), *it, mCardView);
+                    match = true;
+                    break;
+                }
+            }
         }
     }
     mCardView->viewport()->setUpdatesEnabled( true );
