@@ -150,7 +150,7 @@ class AddresseeIconViewItem : public QIconViewItem
           setText( mAddressee.givenName() + " " + mAddressee.familyName() );
 
         QPixmap icon;
-        QPixmap defaultIcon( KGlobal::iconLoader()->loadIcon( "vcard", KIcon::Desktop, 128 ) );
+      
         KABC::Picture pic = mAddressee.photo();
         if ( pic.data().isNull() )
           pic = mAddressee.logo();
@@ -163,13 +163,26 @@ class AddresseeIconViewItem : public QIconViewItem
         else
           icon = img.scaleHeight( 32 );
 #else //KAB_EMBEDDED
+
+        int wid = pic.data().width();
+        int hei = pic.data().height(); 
+        int max = 48; 
+        if ( wid > max || hei > max ) {
+            if ( wid > hei ) {
+                hei = (hei*max)/wid;
+                wid = max;
+            } else {
+                wid = (wid*max)/hei;
+                hei = max;
+            }
+        }
         qDebug("AddresseeIconViewItem::refresh - scale here dependend of the displaysize and the right factor");
-          icon.convertFromImage(img.smoothScale(32, 32));
+        icon.convertFromImage(img.smoothScale(wid, hei));
 #endif //KAB_EMBEDDED
           
-      } else
-        icon = defaultIcon;
-
+        } else {
+            icon = KGlobal::iconLoader()->loadIcon( "vcard", KIcon::Desktop, 128 );
+        }
       setPixmap( icon );
     }
     
@@ -283,6 +296,7 @@ void KAddressBookIconView::doSearch( const QString&  s ,KABC::Field *field )
         for (it = addresseeList.begin(); it != addresseeList.end(); ++it ) {
             if ( (*it).uid().left(2) == "la" && (*it).uid().left(19) == QString("last-syncAddressee-") )
                 continue;
+            bool match = false;
             for ( fieldIt = fieldList.begin(); fieldIt != fieldList.end(); ++fieldIt ) {
 #if QT_VERSION >= 0x030000
                 if (re.search((*fieldIt)->value( *it ).lower()) == 0)
@@ -291,8 +305,23 @@ void KAddressBookIconView::doSearch( const QString&  s ,KABC::Field *field )
 #endif   
                         { 
                             mIconList.append( new AddresseeIconViewItem( fields(), addressBook(), *it, mIconView ));
+                            match = true;
                             break;
                         }
+            } 
+            if ( ! match ) {
+                if ( (*it).matchPhoneNumber( &re ) ) { 
+                    mIconList.append( new AddresseeIconViewItem( fields(), addressBook(), *it, mIconView ));
+                    match = true;
+                    break;
+                }
+            }
+            if ( ! match ) {
+                if ( (*it).matchAddress( &re ) ) { 
+                    mIconList.append( new AddresseeIconViewItem( fields(), addressBook(), *it, mIconView ));
+                    match = true;
+                    break;
+                }
             }
         }
     }
