@@ -1,4 +1,4 @@
-// $Id: kaddressbooktableview.cpp,v 1.22 2005/07/03 14:46:37 zautrix Exp $
+// $Id: kaddressbooktableview.cpp,v 1.24 2005/08/23 21:48:54 zautrix Exp $
 
 #include <qvbox.h>
 #include <qlistbox.h>
@@ -170,6 +170,7 @@ void KAddressBookTableView::doSearch( const QString&  s, KABC::Field *field  )
         for (it = addresseeList.begin(); it != addresseeList.end(); ++it ) {
             if ( (*it).uid().left(2) == "la" && (*it).uid().left(19) == QString("last-syncAddressee-") )
                 continue;
+            bool match = false;
             for ( fieldIt = fieldList.begin(); fieldIt != fieldList.end(); ++fieldIt ) {
 #if QT_VERSION >= 0x030000
                 if (re.search((*fieldIt)->value( *it ).lower()) == 0)
@@ -179,9 +180,24 @@ void KAddressBookTableView::doSearch( const QString&  s, KABC::Field *field  )
                         { 
                             //qDebug("match %s %s %s", pattern.latin1(), (*fieldIt)->value( *it ).latin1(), (*fieldIt)->label().latin1()  );
                             ContactListViewItem *item = new ContactListViewItem(*it, mListView, addressBook(), fields());
+                            match = true;
                             break;
                         }
             }
+            if ( ! match ) {
+                if ( (*it).matchPhoneNumber( &re ) ) {
+                    ContactListViewItem *item = new ContactListViewItem(*it, mListView, addressBook(), fields());
+                    match = true;
+                    break;
+                }
+            } 
+            if ( ! match ) {
+                if ( (*it).matchAddress( &re ) ) {
+                    ContactListViewItem *item = new ContactListViewItem(*it, mListView, addressBook(), fields());
+                    match = true;
+                    break;
+                }
+            }
         }
     }
     // Sometimes the background pixmap gets messed up when we add lots
@@ -318,10 +334,12 @@ void KAddressBookTableView::refresh(QString uid)
     // Sometimes the background pixmap gets messed up when we add lots
     // of items.
     mListView->repaint();
-
+    if ( !currentItem ) 
+        currentItem =  (ContactListViewItem *)mListView->firstChild();
     if ( currentItem ) {
       mListView->setCurrentItem( currentItem );
       mListView->ensureItemVisible( currentItem );
+      mListView->setSelected( currentItem, true );
     }
   } else {
     // Only need to update on entry. Iterate through and try to find it
