@@ -783,9 +783,9 @@ MHviewItem::MHviewItem( const QString&aPath, AccountView *parent )
 {
     m_Path = aPath;
     /* be carefull - the space within settext is wanted - thats why the string twice */
-    wrapper = AbstractMail::getWrapper( m_Path,"Local Folders");
+    wrapper = AbstractMail::getWrapper( m_Path,"Local Mailfolders");
     setPixmap( 0, PIXMAP_LOCALFOLDER );
-    setText( 0, " Local Folders" );
+    setText( 0, i18n(" Local Mailfolders") );
     setOpen( true );
     folder = 0;
 }
