@@ -53,6 +53,7 @@ ComposeMail::ComposeMail( Settings *sett, QWidget *parent, const char *name, boo
     : ComposeMailUI( parent, name, modal )
 {
 
+    topLevelWidget()->setCaption( i18n("Compose mail - Click OK to send ->") );
     mPickLineEdit = 0;
     mEncoding = KOPrefs::instance()->mCurrentCodeName;
     //managed from opiemail now
@@ -223,7 +224,7 @@ void ComposeMail::saveAsDraft()
 }
 void  ComposeMail::clearStatus()
 {
-    topLevelWidget()->setCaption( i18n("Compose mail") );
+    topLevelWidget()->setCaption( i18n("Compose mail - Click OK to send ->") );
 }
 void  ComposeMail::setStatus( QString status )
 {
@@ -424,7 +425,7 @@ void ComposeMail::accept()
     }
 
     if (! checkBoxLater->isChecked() ) {
-        int yesno = QMessageBox::warning(0,i18n("Stop editing message"),
+        int yesno = QMessageBox::warning(0, subjectLine->text().left ( 25 ),
                                          i18n("Send this message?"),
                                          i18n("Yes"),
                                          i18n("Cancel"));
