@@ -47,7 +47,6 @@ int IMAPwrapper::selectMbox(const QString&mbox)
 
 void IMAPwrapper::imap_progress( size_t current, size_t maximum )
 {
-    qApp->processEvents();
     return;
     //qDebug("imap progress %d of %d ",current,maximum  );
     //Global::statusMessage(i18n("Downloading message %1 of %2").arg( current).arg(maximum));
@@ -158,7 +157,6 @@ void IMAPwrapper::login(bool tryTLS) // = true)
       user = account->getUser();
       pass = account->getPassword();
     }
-
     m_imap = mailimap_new( 20, &imap_progress );
 
     /* connect */
@@ -174,9 +172,9 @@ void IMAPwrapper::login(bool tryTLS) // = true)
     }
 
     if ( ssl ) {
-        qDebug("using ssl ");
+        //qDebug("using ssl ");
         err = mailimap_ssl_connect( m_imap, (char*)server.latin1(), port );
-        qDebug("back ");
+        //qDebug("back ");
     } else {
         err = mailimap_socket_connect( m_imap, (char*)server.latin1(), port );
     }
