@@ -2,11 +2,11 @@
 #ifndef __MAILLISTVIEWITEM_H
 #define __MAILLISTVIEWITEM_H
 
-#include <qlistview.h>
+#include <klistview.h>
 #include <libmailwrapper/mailtypes.h>
 #include <libmailwrapper/maildefines.h>
 
-class MailListViewItem:public QListViewItem
+class MailListViewItem:public KListViewItem
 {
 public:
     MailListViewItem(QListView * parent, MailListViewItem * after );
