@@ -23,6 +23,7 @@ extern QStatusBar* globalSstatusBarMainWindow;
 #include "mainwindow.h"
 #include "mailistviewitem.h"
 #include <KDGanttMinimizeSplitter.h>
+#include <libkdepim/kpimglobalprefs.h>
 
 #include "koprefs.h"
 
@@ -165,7 +166,7 @@ MainWindow::MainWindow( QWidget *parent, const char *name, WFlags flags )
 
     //layout->addWidget( folderView );
 
-    mailView = new QListView( split );
+    mailView = new KListView( split );
     mailView->addColumn( i18n( " " ) );
     mailView->addColumn( i18n( "Subject" ),QListView::Manual );
     mailView->addColumn( i18n( "Sender" ),QListView::Manual );
@@ -178,7 +179,9 @@ MainWindow::MainWindow( QWidget *parent, const char *name, WFlags flags )
     mailView->setRootIsDecorated( false );
     statusWidget = new StatusWidget( wrapperBox );
     statusWidget->hide();
-
+    mailView->setSelectionMode( QListView::Multi );   
+    mailView->setMultiSelection( true);
+    mailView->setAlternateBackground(KPimGlobalPrefs::instance()->mAlternateColor );
     //layout->addWidget( mailView );
     //layout->setStretchFactor( folderView, 1 );
     //layout->setStretchFactor( mailView, 2 );
@@ -211,7 +214,7 @@ MainWindow::MainWindow( QWidget *parent, const char *name, WFlags flags )
 //    connect( searchMails, SIGNAL( activated() ), SLOT( slotSearchMails() ) );
     connect( editAccounts, SIGNAL( activated() ), SLOT( slotEditAccounts() ) );
     //mailView->setMultiSelection ( true );
-    mailView->setSelectionMode( QListView::Extended );
+    //mailView->setSelectionMode( QListView::Extended );
     QValueList<int> list;
     int fw = 100;
     if ( QApplication::desktop()->width() > 320 )
@@ -219,7 +222,7 @@ MainWindow::MainWindow( QWidget *parent, const char *name, WFlags flags )
     list.append( fw );
     list.append( 100 );
     split->setSizes( list );
-    QTimer::singleShot( 1000, this, SLOT( slotAdjustColumns() ) );
+    QTimer::singleShot( 100, this, SLOT( slotAdjustColumns() ) );
     mailView->setShowSortIndicator ( true ); 
     QLabel *spacer = new QLabel( toolBar );
     spacer->setBackgroundMode( QWidget::PaletteButton );
@@ -362,18 +365,32 @@ void MainWindow::slotAdjustLayout() {
 
 void MainWindow::slotAdjustColumns()
 {
-    bool hidden = folderView->isHidden();
-    if ( hidden ) folderView->show();
-    folderView->setColumnWidth( 0, folderView->visibleWidth() );
-    if ( hidden ) folderView->hide();
+   
+    if ( !folderView->isHidden() )
+        folderView->setColumnWidth( 0, folderView->visibleWidth() );
 
     mailView->setColumnWidth( 0, 10 );
     mailView->setColumnWidth( 1, 100 );
     mailView->setColumnWidth( 2, 100 );
-    mailView->setColumnWidth( 3, 50 );
-    mailView->setColumnWidth( 4, 120 );
+    mailView->setColumnWidth( 3, 70 );
+    mailView->setColumnWidth( 4, 180 );
     if ( KOPrefs::instance()->mShowToField )
         mailView->setColumnWidth( 5, 100 );
+    mailView->setColumnAlignment( 3, AlignRight);
+}
+void MainWindow::slotAdjustColumnsWide()
+{
+    if ( !folderView->isHidden() )
+        folderView->setColumnWidth( 0, folderView->visibleWidth() );
+
+    mailView->setColumnWidth( 0, 10 );
+    mailView->setColumnWidth( 1, 200 );
+    mailView->setColumnWidth( 2, 200 );
+    mailView->setColumnWidth( 3, 70 );
+    mailView->setColumnWidth( 4, 180 );
+    if ( KOPrefs::instance()->mShowToField )
+        mailView->setColumnWidth( 5, 100 );
+    mailView->setColumnAlignment( 3, AlignRight);
 }
 
 void MainWindow::slotEditSettings()
