@@ -4,7 +4,7 @@
 #define MAINWINDOW_H
 
 #include <qmainwindow.h>
-#include <qlistview.h>
+#include <klistview.h>
 #include <qaction.h>
 #include <qlineedit.h>
 
@@ -34,6 +34,7 @@ public:
 
 public slots:
     virtual void slotAdjustColumns();
+    virtual void slotAdjustColumnsWide();
     virtual void appMessage(const QCString &msg, const QByteArray &data);
     virtual void slotComposeMail();
 
@@ -66,7 +67,7 @@ protected:
     QAction *composeMail, *sendQueued, *showFolders, *searchMails, *deleteMails,
             *editSettings, *editAccounts, *syncFolders;
     AccountView *folderView;
-    QListView *mailView;
+    KListView *mailView;
     QLineEdit* toLE,*fromLE,*subLE;
     //QBoxLayout *layout;
 };
