@@ -541,11 +541,15 @@ void OpieMail::slotShowFolders( bool show )
 {
     if ( show && folderView->isHidden() )
     {
+        slotAdjustColumns();
         folderView->show();
+        //slotAdjustColumns();
     }
     else if ( !show && !folderView->isHidden() )
     {
+        slotAdjustColumnsWide();
         folderView->hide();
+        //slotAdjustColumnsWide();
     }
 }
 
