@@ -957,10 +957,10 @@ void KOAgenda::performItemAction(QPoint viewportPos)
         moveItem->moveRelative(gx - mCurrentCellX,dy);
         int x,y;
         gridToContents(moveItem->cellX(),moveItem->cellYTop(),x,y);
-        moveItem->resize(mGridSpacingX * moveItem->cellWidth(),
+        int diff = moveItem->resizeMe(mGridSpacingX, mGridSpacingX* moveItem->cellWidth(),
                          mGridSpacingY * moveItem->cellHeight());
         moveItem->raise();
-        moveChild(moveItem,x,y);
+        moveChild(moveItem,x+diff,y);
         moveItem = moveItem->nextMultiItem();
       }
     } else if (mActionType == RESIZETOP) {
@@ -982,16 +982,17 @@ void KOAgenda::performItemAction(QPoint viewportPos)
     } else if (mActionType == RESIZELEFT) {
        if (mCurrentCellX <= mActionItem->cellXWidth()) {
          mActionItem->expandLeft(gx - mCurrentCellX);
-         mActionItem->resize(mGridSpacingX * mActionItem->cellWidth(),
-                             mActionItem->height());
+         int diff =  mActionItem->resizeMe(mGridSpacingX ,
+                                           mGridSpacingX * mActionItem->cellWidth(),
+                                           mActionItem->height());
         int x,y;
         gridToContents(mActionItem->cellX(),mActionItem->cellYTop(),x,y);
-        moveChild(mActionItem,x,childY(mActionItem));
+        moveChild(mActionItem,x+diff,childY(mActionItem));
        }
     } else if (mActionType == RESIZERIGHT) {
        if (mCurrentCellX >= mActionItem->cellX()) {
          mActionItem->expandRight(gx - mCurrentCellX);
-         mActionItem->resize(mGridSpacingX * mActionItem->cellWidth(),
+         mActionItem->resizeMe(mGridSpacingX, mGridSpacingX * mActionItem->cellWidth(),
                              mActionItem->height());
        }
     }
@@ -1217,8 +1218,9 @@ void KOAgenda::placeSubCells(KOAgendaItem *placeItem)
         for ( item=conflictItems.first(); item != 0;
               item=conflictItems.next() ) {
             item->setSubCells(maxSubCells);
+            int diff = 0;
             if (mAllDayMode) {
-                item->resize(item->cellWidth() * mGridSpacingX, newSubCellWidth);
+                diff = item->resizeMe( mGridSpacingX, item->cellWidth() * mGridSpacingX, newSubCellWidth);
             } else {
                 item->resize(newSubCellWidth, item->cellHeight() * mGridSpacingY);
             }
@@ -1229,7 +1231,7 @@ void KOAgenda::placeSubCells(KOAgendaItem *placeItem)
             } else {
                 x += item->subCell() * newSubCellWidth;
             }
-            moveChild(item,x,y);  
+            moveChild(item,x+diff,y);  
             // qDebug("moveChild %s %d %d ", item->incidence()->summary().latin1() ,x,y);  
             //item->updateItem();
         }
@@ -1243,8 +1245,9 @@ void KOAgenda::placeSubCells(KOAgendaItem *placeItem)
                       item2=conflictItems2.next() ) {
                     if ( item2->subCells() != maxSubCells) {
                         item2->setSubCells(maxSubCells);
+                        int diff = 0;
                         if (mAllDayMode) {
-                            item2->resize(item2->cellWidth() * mGridSpacingX, newSubCellWidth);
+                            diff = item2->resizeMe(mGridSpacingX, item2->cellWidth() * mGridSpacingX, newSubCellWidth);
                         } else {
                             item2->resize(newSubCellWidth, item2->cellHeight() * mGridSpacingY);
                         }
@@ -1255,7 +1258,7 @@ void KOAgenda::placeSubCells(KOAgendaItem *placeItem)
                         } else {
                             x += item2->subCell() * newSubCellWidth;
                         }
-                        moveChild(item2,x,y);  
+                        moveChild(item2,x+diff,y);  
                         //qDebug("setttttt %d %s",maxSubCells, item2->text().latin1() );
                     }
                 }
@@ -1264,11 +1267,12 @@ void KOAgenda::placeSubCells(KOAgendaItem *placeItem)
     } else {
         placeItem->setSubCell(0);
         placeItem->setSubCells(1);
-        if (mAllDayMode) placeItem->resize(placeItem->width(),mGridSpacingY);
+        int diff = 0;
+        if (mAllDayMode) diff = placeItem->resizeMe( mGridSpacingX, placeItem->width(),mGridSpacingY);
         else placeItem->resize(mGridSpacingX,placeItem->height());
         int x,y;
         gridToContents(placeItem->cellX(),placeItem->cellYTop(),x,y);
-        moveChild(placeItem,x,y);
+        moveChild(placeItem,x+diff,y);
     }
     placeItem->setConflictItems(conflictItems);
   //   for ( item=conflictItems.first(); item != 0;
@@ -1395,11 +1399,12 @@ void KOAgenda::finishUpdate()
         if ( !item->checkLayout() ) {
             //qDebug(" conflictitem found ");
             int newSubCellWidth;
+            int diff = 0;
             if (mAllDayMode) newSubCellWidth = mGridSpacingY / item->subCells();
             else newSubCellWidth = mGridSpacingX / item->subCells();
 
             if (mAllDayMode) {
-                item->resize(item->cellWidth() * mGridSpacingX, newSubCellWidth);
+                diff = item->resizeMe(mGridSpacingX, item->cellWidth() * mGridSpacingX, newSubCellWidth);
             } else {
                 item->resize(newSubCellWidth, item->cellHeight() * mGridSpacingY);
             }
@@ -1410,7 +1415,7 @@ void KOAgenda::finishUpdate()
             } else {
                 x += item->subCell() * newSubCellWidth;
             }
-            moveChild(item,x,y); 
+            moveChild(item,x+diff,y); 
         }
     }
     for ( item=mItems.first(); item != 0; item=mItems.next() ) {
@@ -1467,7 +1472,7 @@ void KOAgenda::drawContentsToPainter( QPainter* paint, bool backgroundOnly )// i
    
     //--cx;++cw;
     int lGridSpacingY = mGridSpacingY*2;
-    int selDay;
+    uint selDay;
     QDate curDate = QDate::currentDate();
     if ( !backgroundOnly ) {
         for ( selDay = 0; selDay < mSelectedDates.count();  ++selDay)
@@ -1481,7 +1486,7 @@ void KOAgenda::drawContentsToPainter( QPainter* paint, bool backgroundOnly )// i
                     if (y2 > cy+ch-1) y2=cy+ch-1;
                     if (x2 >= x1 && y2 >= y1) {
                         int gxStart = selDay;
-                        int gxEnd = gxStart ;
+                        //int gxEnd = gxStart ;
                         int xStart = KOGlobals::self()->reverseLayout() ?
                             (mColumns - 1 - gxStart)*mGridSpacingX :
                             gxStart*mGridSpacingX;
@@ -1831,12 +1836,12 @@ KOAgendaItem *KOAgenda::insertAllDayItem (Incidence *event,QDate qd,int XBegin,i
    if (!mAllDayMode) {
     return 0;
   }
-
+   //qDebug("insertallday %s  -- %d  - %d ",qd.toString().latin1(), XBegin, XEnd );
   KOAgendaItem *agendaItem = getNewItem(event,qd,viewport());
 
   agendaItem->setCellXY(XBegin,0,0);
   agendaItem->setCellXWidth(XEnd);
-  agendaItem->resize(mGridSpacingX * agendaItem->cellWidth(),mGridSpacingY);
+  agendaItem->resizeMe(mGridSpacingX, mGridSpacingX * agendaItem->cellWidth(),mGridSpacingY, true );
 
   //addChild(agendaItem,XBegin*mGridSpacingX,0);
   mItems.append(agendaItem);
@@ -1922,6 +1927,7 @@ void KOAgenda::resizeEvent ( QResizeEvent *ev )
     mSelectionHeight = 0;
     mResizeTimer.start( 150 , true );
     computeSizes(); 
+    QScrollView::resizeEvent( ev );
     return;
 
 }
@@ -1941,10 +1947,11 @@ void KOAgenda::computeSizes()
         int subCellWidth;
         for ( item=mItems.first(); item != 0; item=mItems.next() ) {
             subCellWidth = mGridSpacingY / item->subCells();
-            item->resize(mGridSpacingX * item->cellWidth(),subCellWidth);
-            moveChild(item,KOGlobals::self()->reverseLayout() ?
+            int diff = 0;
+            diff = item->resizeMe(mGridSpacingX ,mGridSpacingX * item->cellWidth(),subCellWidth);
+            moveChild(item,(KOGlobals::self()->reverseLayout() ?
                       (mColumns - 1 - item->cellX()) * mGridSpacingX :
-                      item->cellX() * mGridSpacingX,
+                            item->cellX() * mGridSpacingX) + diff,
                       item->subCell() * subCellWidth);
         }
         KOPrefs::instance()->mAllDaySize = mGridSpacingY;
@@ -2181,7 +2188,7 @@ void KOAgenda::restorePosition()
         if ( mContentPosition == 0 ) 
             posY = 0;
         else
-            posY =  (max/mContentPosition)-(viewport()->height()/2);
+            posY =  (int) ((max/mContentPosition)-(viewport()->height()/2));
     setContentsPos (0, posY );
     //qDebug("posY %d hei %d", posY, max);
 
@@ -2202,7 +2209,7 @@ void KOAgenda::printSelection()
 {
 #ifdef DESKTOP_VERSION
     if ( mStartCellY == mCurrentCellY ) {
-        int result = QMessageBox::warning( this, i18n("KO/Pi: Warning!"),
+        QMessageBox::warning( this, i18n("KO/Pi: Warning!"),
                                            i18n("Nothing selected!\n\nThis prints the full width of the Agenda view as you see it!\n\nTo determine the vertical range of the printing, please select\na vertical range (with the left mouse button down) in one column. "),
                                            i18n("OK"), 0, 0,
                                            0, 1 );
@@ -2240,22 +2247,22 @@ void KOAgenda::printSelection()
     else
         scale = dy;
     // set the scale
-    p.drawText( offset* scale, offset* scale*3/4, date );
+    p.drawText( (int) (offset* scale), (int) (offset* scale*3/4), date );
 
-    int selDay;
+    uint selDay;
     float widOffset = ((float) m.width()-offset) / ((float)(mSelectedDates.count()));
     float startX = 1;
     for ( selDay = 0; selDay < mSelectedDates.count();  ++selDay)
       {
 	QString text = KGlobal::locale()->formatDate( mSelectedDates[selDay],true );
-	p.setClipRect(offset* scale+startX , 0, widOffset-4, offset* scale+(2*hei* scale) );
-	p.drawText( offset* scale+startX, (offset+hei)* scale, text );
+	p.setClipRect((int) (offset* scale+startX) , 0, (int) (widOffset-4), (int) (offset* scale+(2*hei* scale)) );
+	p.drawText( (int) (offset* scale+startX), (int) ((offset+hei)* scale), text );
 	startX += widOffset;
 	
       }
-    p.translate( offset* scale,offset* scale+ (-y * scale)+(2*hei* scale));
+    p.translate( (int) (offset* scale),(int) (offset* scale+ (-y * scale)+(2*hei* scale)));
     p.scale( scale, scale );
-    p.setClipRect(  offset* scale, offset* scale+(2*hei* scale), w*scale, h*scale );
+    p.setClipRect(  (int) (offset* scale), (int) (offset* scale+(2*hei* scale)), (int) (w*scale), (int) (h*scale) );
     // now printing with y offset:  2 hei
     // p.translate( 0, -y*scale);
 
