@@ -48,7 +48,7 @@ class MarcusBains : public QFrame {
   public:
     MarcusBains(KOAgenda *agenda=0,const char *name=0);
     virtual ~MarcusBains();
-
+    void hideMe();
   public slots:
     void updateLocation(bool recalculate=false);
     void updateLoc();
@@ -128,6 +128,7 @@ class KOAgenda : public QScrollView
     void setPopup( KOEventPopupMenu * p ) { mAllAgendaPopup = p; }
     void shrinkPixmap();
     QTime getEndTime();
+    bool invalidPixmap();
 
   public slots:
     void slotContentMove(int,int);
