@@ -582,12 +582,12 @@ void KOAgendaItem::computeText()
                 if ( mIncidence->doesRecur() ) {
                     mDisplayedText += " (" + mIncidence->recurrence()->recurrenceText() + ")";
                 } else {
-                    mDisplayedText += ": " +KGlobal::locale()->formatDate((static_cast<Event*>(mIncidence))->dtStart().date(), true) + " - " + KGlobal::locale()->formatDate((static_cast<Event*>(mIncidence))->dtEnd().date(), true) ;
+                    int dur = 1+ (static_cast<Event*>(mIncidence))->dtStart().date().daysTo( (static_cast<Event*>(mIncidence))->dtEnd().date() );
+                    mDisplayedText += ": " +KGlobal::locale()->formatDate((static_cast<Event*>(mIncidence))->dtStart().date(), true) + " - " + KGlobal::locale()->formatDate((static_cast<Event*>(mIncidence))->dtEnd().date(), true) + " ("+QString::number( dur )+i18n(" days") +")" ;
                 }
             }  
         }
     }
-    
     if ( !mIncidence->location().isEmpty() ) {
         if ( mAllDay )
             mDisplayedText += " (";
@@ -656,7 +656,26 @@ int KOAgendaItem::cellHeight()
     }
     return ret;
 }
-
+// it may be that allday agenda items have a needed width > 32000
+// this code is to fix this problem
+int KOAgendaItem::resizeMe( int grid, int wid, int hei, bool invalidWidth )
+{
+    int diff = 0;
+    if ( mCellX < -3  && mAllDay  ) {
+        diff = (mCellX + 3) * -grid;
+        //qDebug("%s: cellX %d diff %d wid %d grid %d ", mDisplayedText.latin1(),  mCellX, diff, wid, grid); 
+        if ( diff >= wid ) {
+            // qDebug("KOAgendaItem::resizeMe: diff >= wid: diff %d wid %d ", diff, wid);
+            //diff = 0;
+        }
+    }
+    if ( (!invalidWidth && wid == width() ) || diff >= wid  )
+        resize( wid, hei );
+    else
+        resize( wid - diff, hei );
+    //qDebug("wid %d x %d ", width(), x());
+    return diff;
+}
 /*
   Return height of item in units of agenda cells
 */
