@@ -108,6 +108,8 @@ class KOAgendaItem : public QWidget
     void recreateIncidence();
     bool checkLayout();
     void initColor ();
+    bool isAllDay() { return mAllDay; }
+    int resizeMe( int grid, int wid, int hei, bool invalidWidth = false );
   public slots:
     bool updateIcons( QPainter *, bool );
     void select(bool=true);
