@@ -717,6 +717,8 @@ void KOAgendaView::createDayLabels()
     dlf.setBold( true );
     int selCount = mSelectedDates.count();
     int widModulo = maxWid - (mAgenda->gridSpacingX() * selCount)+1;
+    if ( widModulo < 0 || widModulo > selCount )
+        widModulo = 0;
     QString dayTest = "Mon 20";
     //QString dayTest = "Mon 20";
     int wid = fm.width( dayTest );
@@ -1002,11 +1004,12 @@ void KOAgendaView::updateEventDates(KOAgendaItem *item, int type)
 
     int xxx = item->cellX();
     //qDebug("KOAgendaView::updateEventDates %d %d %d %d %d", xxx, mMinY.at(xxx),mMaxY.at(xxx),item->cellYTop(),item->cellYBottom() );
-    if ( mMinY.at(xxx) > item->cellYTop() )
-        mMinY.at(xxx) = item->cellYTop();
-    if ( mMaxY.at(xxx) < item->cellYBottom() )
-        mMaxY.at(xxx) = item->cellYBottom();
-    
+    if ( xxx >= 0 && xxx < mMinY.count() &&  !item->isAllDay() ) {
+        if ( mMinY.at(xxx) > item->cellYTop() )
+            mMinY.at(xxx) = item->cellYTop();
+        if ( mMaxY.at(xxx) < item->cellYBottom() )
+            mMaxY.at(xxx) = item->cellYBottom();
+    }
     QDateTime startDt,endDt;
     QDate startDate;
     int lenInSecs;
@@ -1234,7 +1237,6 @@ void KOAgendaView::fillAgenda()
                     } else {
                         mAllDayAgenda->insertAllDayItem(event,currentDate,curCol,curCol);
                     }
-                    
                 } else {
                     if (beginX <= 0 && curCol == 0) {
                         mAllDayAgenda->insertAllDayItem(event,currentDate,beginX,endX);
