@@ -458,6 +458,9 @@ void KODayMatrix::updateViewTimed()
             (recurType == Recurrence::rWeekly && !KOPrefs::instance()->mWeeklyRecur)) {
             continue;
         }
+        if ( !KOPrefs::instance()->mLongAllday && event->doesFloat()&& event->isMultiDay() ) {
+            continue;
+        }
         if ( event->doesRecur() ) {
             bool last;
             QDateTime incidenceStart = event->recurrence()->getPreviousDateTime( QDateTime( mStartDate ) , &last );
@@ -684,6 +687,9 @@ void KODayMatrix::updateEvents()
              !KOPrefs::instance()->mWeeklyRecur ) ) {
         numEvents--;
       }
+      if ( !KOPrefs::instance()->mLongAllday && event->doesFloat()&& event->isMultiDay() ) {
+          numEvents--;
+      }
     } 
     if ( numEvents ) 
         eDays.setBit(i);
