@@ -117,8 +117,6 @@ KOEditorDetails::KOEditorDetails (int spacing,QWidget* parent,const char* name)
   connect(mNameEdit,SIGNAL(textChanged(const QString &)),
           SLOT(updateAttendeeItem()));
 
-  mUidEdit = new QLineEdit(0);
-  mUidEdit->setText("");
 
   QLabel *emailLabel = new QLabel(this);
   emailLabel->setText(i18n("Email:"));
@@ -355,7 +353,7 @@ void KOEditorDetails::setDefaults()
   mOrganizerLabel->setText(i18n("Organizer: %1").arg(KOPrefs::instance()->email()));
 
   mNameEdit->setText("");
-  mUidEdit->setText("");
+  mUidEdit = "";
   mEmailEdit->setText("");
   mRoleCombo->setCurrentItem( 0 );
   mStatusCombo->setCurrentItem( 0 );
@@ -418,7 +416,7 @@ void KOEditorDetails::updateAttendeeInput()
 void KOEditorDetails::clearAttendeeInput()
 {
   mNameEdit->setText("");
-  mUidEdit->setText("");
+  mUidEdit = "";
   mEmailEdit->setText("");
   mRoleCombo->setCurrentItem(0);
   mStatusCombo->setCurrentItem(0);
@@ -431,7 +429,7 @@ void KOEditorDetails::fillAttendeeInput( AttendeeListItem *aItem )
   Attendee *a = aItem->data();
   mDisableItemUpdate = true;
   mNameEdit->setText(a->name());
-  mUidEdit->setText(a->uid());
+  mUidEdit = a->uid();
   mEmailEdit->setText(a->email());
   mRoleCombo->setCurrentItem(a->role());
   mStatusCombo->setCurrentItem(a->status());
@@ -471,7 +469,7 @@ void KOEditorDetails::updateAttendeeItem()
   Attendee *a = aItem->data();
 
   a->setName( mNameEdit->text() );
-  a->setUid( mUidEdit->text() );
+  a->setUid( mUidEdit );
   a->setEmail( mEmailEdit->text() );
   if ( mEmailEdit->text().isEmpty() )
       mRsvpButton->setChecked( false );
