@@ -125,7 +125,13 @@ void KOEditorGeneral::initHeader(QWidget *parent,QBoxLayout *topLayout)
     else {
         headerLayout->addWidget(mLocationEdit,1,1);
         headerLayout->addWidget(mCalendarBox,1,2);
-        headerLayout->setColStretch( 1, 3);
+        int str = 3;
+        if ( QApplication::desktop()->width() < 640 ) {
+            --str;
+            if ( QApplication::desktop()->width() < 320 )
+                --str;
+        }
+        headerLayout->setColStretch( 1, str);
         headerLayout->setColStretch( 2, 1);
     }
     
