@@ -208,12 +208,7 @@ void KOEditorGeneralTodo::setDefaults(QDateTime due,bool allDay)
   KOEditorGeneral::setDefaults(allDay);
 
   mTimeButton->setChecked( !allDay );
-  if(mTimeButton->isChecked()) {
-    mTimeButton->setEnabled(true);
-  }
-  else {
-    mTimeButton->setEnabled(false);
-  }
+  mTimeButton->setEnabled( !allDay );
   
   enableTimeEdits( !allDay );
   if ( due.isValid() ) {
@@ -252,6 +247,8 @@ void KOEditorGeneralTodo::readTodo(Todo *todo)
   KOEditorGeneral::readIncidence(todo);
 
   QDateTime dueDT;
+  mTimeButton->setChecked( !todo->doesFloat() );
+  mTimeButton->setEnabled( !todo->doesFloat() );
   
   if (todo->hasDueDate()) {
     enableAlarmEdit(true);
@@ -259,6 +256,7 @@ void KOEditorGeneralTodo::readTodo(Todo *todo)
     mDueDateEdit->setDate(todo->dtDue().date());
     mDueTimeEdit->setTime(todo->dtDue().time());
     mDueCheck->setChecked(true);
+    mTimeButton->setEnabled( true );
   } else {
     alarmDisable(true);
     mDueDateEdit->setEnabled(false);
@@ -272,6 +270,7 @@ void KOEditorGeneralTodo::readTodo(Todo *todo)
     mStartDateEdit->setDate(todo->dtStart().date());
     mStartTimeEdit->setTime(todo->dtStart().time());
     mStartCheck->setChecked(true);
+    mTimeButton->setEnabled( true );
   } else {
     mStartDateEdit->setEnabled(false);
     mStartTimeEdit->setEnabled(false);
@@ -280,7 +279,6 @@ void KOEditorGeneralTodo::readTodo(Todo *todo)
     mStartCheck->setChecked(false);
   }
 
-  mTimeButton->setChecked( !todo->doesFloat() );
 
   mCompletedCombo->setCurrentItem(todo->percentComplete() / 20);
   if (todo->isCompleted() && todo->hasCompletedDate()) {
