@@ -33,6 +33,7 @@
 #include <qmultilineedit.h>
 #include <qlistview.h>
 #include <qradiobutton.h>
+#include <qbuttongroup.h>
 
 #include <kdialogbase.h>
 
@@ -217,6 +218,7 @@ class RecurrenceRangeWidget : public QWidget, public RecurrenceRangeBase
     Q_OBJECT
   public:
     RecurrenceRangeWidget( QWidget *parent = 0, const char *name = 0 );
+    ~RecurrenceRangeWidget();
 
     void setDefaults( const QDateTime &from );
 
@@ -233,6 +235,7 @@ class RecurrenceRangeWidget : public QWidget, public RecurrenceRangeBase
     void showCurrentRange();
 
   private:
+    QButtonGroup *mRangeButtonGroup;
     QGroupBox *mRangeGroupBox;
     QLabel *mStartDateLabel;
     QRadioButton *mNoEndDateButton;
