@@ -110,6 +110,16 @@ void KOEventViewer::printMe()
 void KOEventViewer::setSource(const QString& n)
 {
 
+    if ( n.left(8) == "todo_uid" ) {
+        int midstr = 9;
+#ifdef DESKTOP_VERSION
+        midstr = 11;
+#endif        
+        //qDebug("-%s- ", n.mid(midstr).latin1());
+        emit showIncidence(  n.mid(midstr) );
+        return;
+    }
+
     if ( n.left(3) == "uid" ) 
 #ifdef DESKTOP_VERSION
         {
@@ -282,6 +292,7 @@ void KOEventViewer::appendEvent(Event *event, int mode )
     topLevelWidget()->setCaption(i18n("Event Viewer"));
     if ( mode == 0 ) {
         addTag("h2",deTag(event->summary()));
+        formatReadOnly(event);
     }
     else {
         if ( mColorMode == 1 ) {
@@ -296,6 +307,7 @@ void KOEventViewer::appendEvent(Event *event, int mode )
         } else {
             addTag("h2",i18n( "Remote: " ) +deTag(event->summary()));
         } 
+        formatReadOnly(event);
         addTag("h3",i18n( "Last modified: " ) + KGlobal::locale()->formatDateTime(event->lastModified(),shortDate, true ) );
         if ( mColorMode )
             mText += "</font>";
@@ -335,9 +347,9 @@ void KOEventViewer::appendEvent(Event *event, int mode )
         addTag("p","<b>"+i18n("Location: ")+"</b>"+  deTag(event->location() ) );
         mMailSubject += i18n(" at ") + event->location();
     }
-    if (event->recurrence()->doesRecur()) {
+    if (event->doesRecur()) {
 
-        QString recurText = event->recurrence()->recurrenceText();
+        QString recurText = event->recurrenceText();
         addTag("p","<em>" + i18n("This is a %1 recurring event.").arg(recurText ) + "</em>");
         bool ok;
         QDate start = QDate::currentDate();
@@ -388,7 +400,6 @@ void KOEventViewer::appendEvent(Event *event, int mode )
   
     formatCategories(event);
 
-    formatReadOnly(event);
     formatAttendees(event);
   
     if ( KOPrefs::instance()->mEVshowCreated ) {
@@ -428,8 +439,10 @@ void KOEventViewer::appendTodo(Todo *event, int mode )
     topLevelWidget()->setCaption(i18n("Todo Viewer"));
     bool shortDate = KOPrefs::instance()->mShortDateInViewer;
     bool wideScreen = ( QApplication::desktop()->width() >= 640 );
-    if (mode == 0 )
+    if (mode == 0 ) {
         addTag("h2",deTag(event->summary()));
+        formatReadOnly(event);
+    }
     else { 
         if ( mColorMode == 1 ) {
             mText +="<font color=\"#00A000\">";
@@ -442,6 +455,7 @@ void KOEventViewer::appendTodo(Todo *event, int mode )
         } else {
             addTag("h2",i18n( "Remote: " ) +deTag(event->summary()));
         }
+        formatReadOnly(event);
         addTag("h3",i18n( "Last modified: " ) + KGlobal::locale()->formatDateTime(event->lastModified(),shortDate, true ) );
         if ( mColorMode )
             mText += "</font>";
@@ -467,7 +481,7 @@ void KOEventViewer::appendTodo(Todo *event, int mode )
    
    
 
-    if (event->recurrence()->doesRecur()) {
+    if (event->doesRecur()) {
 
         QString recurText = event->recurrence()->recurrenceText();
         addTag("p","<em>" + i18n("This is a %1 recurring todo.").arg(recurText ) + "</em>");
@@ -503,7 +517,6 @@ void KOEventViewer::appendTodo(Todo *event, int mode )
 
     formatCategories(event);
 
-    formatReadOnly(event);
     formatAttendees(event);
     
     if ( KOPrefs::instance()->mEVshowCreated ) {
@@ -527,14 +540,26 @@ void KOEventViewer::appendTodo(Todo *event, int mode )
     } 
     if ( event->relatedTo() ) {
         addTag("b",i18n("Parent todo:<br>"));
-        mText.append(deTag(event->relatedTo()->summary())+" [" +QString::number(event->relatedTo()->priority()) + "/" + QString::number(((Todo*)event->relatedTo())->percentComplete())+"%] <br>");
+
+        QString t_name = "[" +QString::number(event->relatedTo()->priority()) + "/" + QString::number(((Todo*)event->relatedTo())->percentComplete())+"%] ";// +event->relatedTo()->summary());
+
+        mText += t_name;
+        mText += "<a href=\"todo_uid:" + event->relatedTo()->uid() + "\">";
+        mText += deTag(event->relatedTo()->summary());
+        mText += "</a><br>";
+
+        //        mText.append(deTag("[" +QString::number(event->relatedTo()->priority()) + "/" + QString::number(((Todo*)event->relatedTo())->percentComplete())+"%] " +event->relatedTo()->summary()) +"<br>");
     }
     QPtrList<Incidence> Relations = event->relations();
     Incidence *to;
     if ( Relations.first() )
         addTag("b",i18n("Sub todos:<br>"));
     for (to=Relations.first();to;to=Relations.next()) {
-        mText.append( deTag(to->summary())+" [" +QString::number(to->priority()) + "/" + QString::number(((Todo*)to)->percentComplete())+"%]<br>");
+        QString t_name = "[" +QString::number(((Todo*)to)->priority()) + "/" + QString::number(((Todo*)to)->percentComplete())+"%] ";// +to->relatedTo()->summary());
+        mText += t_name;
+        mText += "<a href=\"todo_uid:" + to->uid() + "\">";
+        mText += deTag(to->summary());
+        mText += "</a><br>";
         
     }  
 
@@ -685,19 +710,24 @@ void KOEventViewer::formatAttendees(Incidence *event)
 void KOEventViewer::appendJournal(Journal *jour, int mode )
 { 
     bool shortDate = KOPrefs::instance()->mShortDateInViewer;
+    QString text_d = i18n("Journal from: ");
+    if ( !jour->summary().isEmpty() )
+        text_d = jour->summary();
     if (mode == 0 ) {
-        addTag("h2",i18n("Journal from: "));
+        addTag("h2", text_d );
     }
     else {
         if ( mode == 1 ) {
-            addTag("h2",i18n( "Local: " ) +i18n("Journal from: "));
+            addTag("h3",i18n( "Local: " ) + text_d );
         } else {
-            addTag("h2",i18n( "Remote: " ) +i18n("Journal from: ")); 
+            addTag("h3",i18n( "Remote: " ) + text_d ); 
         } 
     }
-    topLevelWidget()->setCaption("Journal Viewer");
-    mText.append(i18n("<h3> %1 </h3> ").arg(jour->dtStartDateStr(KOPrefs::instance()->mShortDateInViewer)));
-    addTag("b",i18n( "Last modified: " ) + KGlobal::locale()->formatDateTime(jour->lastModified(),shortDate ) );
+    topLevelWidget()->setCaption(i18n("Journal viewer"));
+    mText.append(i18n("<h3> %1 </h3> ").arg(jour->dtStartDateStr(KOPrefs::instance()->mShortDateInViewer))); 
+    formatReadOnly(jour);
+    addTag("p","<b>"+i18n( "Last modified: " ) + "</b>"+KGlobal::locale()->formatDateTime(jour->lastModified(),shortDate ) );
+   
     if (!jour->description().isEmpty()) {
         addTag("p",deTag(jour->description()));
     }
@@ -706,6 +736,10 @@ void KOEventViewer::appendJournal(Journal *jour, int mode )
 
 void KOEventViewer::formatReadOnly(Incidence *event)
 {
+    int id = event->calID();
+    if ( id > 1 ) {
+        addTag("p", "<em>("+i18n("Calendar:")+" " + KOPrefs::instance()->getCalendar( id )->mName + ")</em>");
+    }
     if (event->isReadOnly()) {
         addTag("p","<em>(" + i18n("read-only") + ")</em>");
     }
