@@ -30,6 +30,7 @@
 #include <qtextstream.h>
 #include <qtextcodec.h>
 #include <qwhatsthis.h>
+#include <qdir.h>
 
 
 #include <libkcal/calfilter.h>
@@ -407,16 +408,16 @@ void KOCalEditView::addCal()
 }
 int KOCalEditView::addCalendar( QString name, QString file, bool ask )
 {
-  
+    file = QDir::convertSeparators( file ); 
     QFileInfo fi ( file );
     QString absFile = file;
     bool isRelative = false;
     if ( fi.isRelative() ) {
         isRelative = true; 
-        absFile = KGlobalSettings::calendarDir()+file;
+        absFile = QDir::convertSeparators( KGlobalSettings::calendarDir()+file );
         fi.setFile( absFile );
     } else {
-        QString cd = KGlobalSettings::calendarDir();
+        QString cd = QDir::convertSeparators( KGlobalSettings::calendarDir() );
         if (  file.left( cd.length() ) ==  cd ) {
             isRelative = true; 
             file = fi.fileName ();
