@@ -141,12 +141,10 @@ bool ListItemVisitor::visit(Event *e)
     mItem->setText(9,e->categoriesStr());
     mItem->setText(10, KOPrefs::instance()->calName( e->calID() ));
     mItem->setText(11, KGlobal::locale()->formatDateTime( e->lastModified(), true, true ));
+    mItem->setSortKey(11,e->lastModifiedSortKey());
 
     QString key; 
-    QDate d = e->lastModified().date();
-    QTime t = e->lastModified().time();
-    key.sprintf("%04d%02d%02d%02d%02d%02d",d.year(),d.month(),d.day(),t.hour(),t.minute(),t.second() );
-    mItem->setSortKey(12,key);
+    QTime t;
     t = e->doesFloat() ? QTime(0,0) : e->dtStart().time();
     key.sprintf("%04d%02d%02d%02d%02d",ds.year(),ds.month(),ds.day(),t.hour(),t.minute());
     mItem->setSortKey(1,key);
@@ -200,11 +198,10 @@ bool ListItemVisitor::visit(Todo *t)
     mItem->setText(9,t->categoriesStr());
     mItem->setText(10, KOPrefs::instance()->calName( t->calID() ));
     mItem->setText(11, KGlobal::locale()->formatDateTime( t->lastModified(), true, true ));
+    mItem->setSortKey(11,t->lastModifiedSortKey());
     QString key;
-    QDate d = t->lastModified().date();
-    QTime tm = t->lastModified().time();
-    key.sprintf("%04d%02d%02d%02d%02d%02d",d.year(),d.month(),d.day(),tm.hour(),tm.minute(),tm.second() );
-    mItem->setSortKey(11,key);
+    QDate d;
+    QTime tm;
     if (t->hasDueDate()) {
         d = t->dtDue().date();
         tm = t->doesFloat() ? QTime(0,0) : t->dtDue().time();
@@ -246,17 +243,13 @@ bool ListItemVisitor::visit(Journal * j)
     mItem->setText(9,j->categoriesStr());
     mItem->setText(10, KOPrefs::instance()->calName( j->calID() ));
     mItem->setText(11, KGlobal::locale()->formatDateTime( j->lastModified(), true, true ));
+    mItem->setSortKey(11,j->lastModifiedSortKey());
 
     QString key; 
-    QDate d = j->lastModified().date();
-    QTime tm = j->lastModified().time();
-    key.sprintf("%04d%02d%02d%02d%02d%02d",d.year(),d.month(),d.day(),tm.hour(),tm.minute(),tm.second() );
-    mItem->setSortKey(12,key);
+    QDate d;
     d = j->dtStart().date();
     key.sprintf("%04d%02d%02d",d.year(),d.month(),d.day());
     mItem->setSortKey(1,key);
-    mItem->setSortKey(7,key);
-
     return true;
 }
 
