@@ -82,6 +82,7 @@ KNoScrollListBox::KNoScrollListBox(QWidget *parent,const char *name)
 #ifndef DESKTOP_VERSION
     QPEApplication::setStylusOperation( viewport(), QPEApplication::RightOnHold );
 #endif 
+    mBlockDeselect = false;
     mWT = new KNOWhatsThis(this);
     resetOnFocusIn = true;
     setVScrollBarMode(QScrollView::AlwaysOff);
@@ -135,13 +136,18 @@ void KNoScrollListBox::focusInEvent ( QFocusEvent * e )
 }
 void KNoScrollListBox::focusOutEvent ( QFocusEvent * e )
 {
+  if ( ! mBlockDeselect ) {
     int i =  currentItem ();
     if ( i >= 0 ) {
-        setSelected ( i, false ); 
+      setSelected ( i, false ); 
     }
     QListBox::focusOutEvent ( e ); 
+  }
     setVScrollBarMode(QScrollView::AlwaysOff);
     setHScrollBarMode(QScrollView::AlwaysOff);
+    if ( ! mBlockDeselect )
+      emit highlightIncidence( 0, (MonthViewCell*)this, 0 );
+    mBlockDeselect = false;
 }
 
 QString KNoScrollListBox::getWhatsThisText(QPoint p) 
@@ -201,7 +207,7 @@ void KNoScrollListBox::keyPressEvent(QKeyEvent *e)
             break;
         }
         if ( count () ) { 
-            if ( currentItem()+1 == count () ) {
+            if ( ((uint)currentItem()+1) == count () ) {
                 emit nextCell();
             } else {
                 setCurrentItem((currentItem()+1)%count());
@@ -242,7 +248,7 @@ void KNoScrollListBox::keyPressEvent(QKeyEvent *e)
 void KNoScrollListBox::oneDown()
 {
     if ( count () ) {  
-        if ( currentItem()+1 == count () ) {
+        if ( ((uint)currentItem()+1) == count () ) {
             emit nextCell();
         } else {
             resetOnFocusIn = false;
@@ -277,27 +283,19 @@ void KNoScrollListBox::mousePressEvent(QMouseEvent *e)
     }
 }
 
-MonthViewItem::MonthViewItem( Incidence *incidence, QDate qd, const QString & s)
+MonthViewItem::MonthViewItem( Incidence *incidence, const QString & s)
     : QListBoxItem()
 {
     mblockRepaint = true;
-    setText( s );
-    mMultiday = 0; 
-    mIncidence = incidence;
-    mDate = qd;
-    mRecur = false;
-    mAlarm = false;
-    mReply = false;
-    mInfo = false;
-    mdayPos = 0;
     isWeekItem = KOPrefs::instance()->mMonthViewWeek;
+    recycle( incidence, s );
 }
-void MonthViewItem::recycle( Incidence *incidence, QDate qd, const QString & s)
-{
+void MonthViewItem::recycle( Incidence *incidence,  const QString & s)
+{ 
+    mDisplayHighlighted = false;
     setText( s );
     mMultiday = 0; 
     mIncidence = incidence;
-    mDate = qd;
     mRecur = false;
     mAlarm = false;
     mReply = false;
@@ -305,9 +303,32 @@ void MonthViewItem::recycle( Incidence *incidence, QDate qd, const QString & s)
     mdayPos = 0;
 }
 
+bool MonthViewItem::setHighlightedFalse()
+{
+    if ( !mDisplayHighlighted )
+        return false;
+    mDisplayHighlighted = false;
+    return true;
+}
+
+bool MonthViewItem::setHighlighted( Incidence * inc )
+{
+    if ( inc == mIncidence ) {
+        if ( mDisplayHighlighted )
+            return false;
+        mDisplayHighlighted = true;
+        return true;
+    } else {
+        if ( !mDisplayHighlighted )
+            return false;
+        mDisplayHighlighted = false;
+        return true;
+    }
+    return false;
+}
 void MonthViewItem::paint(QPainter *p)
 {
-    if ( mblockRepaint ) {
+    if ( mblockRepaint || !mIncidence ) {
         return;
     }
 #if QT_VERSION >= 0x030000
@@ -315,22 +336,27 @@ void MonthViewItem::paint(QPainter *p)
 #else
     bool sel = selected();
 #endif 
-
-
-    if (KOPrefs::instance()->mMonthViewUsesCategoryColor)
-        {
-            p->setBackgroundColor( palette().color( QPalette::Normal,  \
-                                                    sel ? QColorGroup::Highlight : QColorGroup::Background ) );
-            p->eraseRect( 0, 0, listBox()->maxItemWidth(), height( listBox() ) );
-        }
+    int heihei = height( listBox () );
     int x = 1;
+    if (KOPrefs::instance()->mMonthViewUsesCategoryColor || mDisplayHighlighted || sel )
+        {
+           
+            p->setBackgroundColor( palette().color( QPalette::Normal,  \
+                                                    sel ||mDisplayHighlighted  ? QColorGroup::Highlight : QColorGroup::Background ) );
+            p->eraseRect( 0, 0, listBox()->maxItemWidth(), heihei );
+        }
+   
     //int y = 3;//(height() - mRecurPixmap.height()) /2; 
     int size = PIXMAP_SIZE;
     if ( QApplication::desktop()->width() < 300 )
         size = 3;
-    int heihei = height( listBox () );
     int y = (heihei - size -1 ) /2; 
 
+    if ( mIncidence->calID() > 1 ) {
+        p->fillRect ( x, y-2,size,size+4, KOPrefs::instance()->defaultColor( mIncidence->calID() ) );
+        p->drawRect ( x, y-2,size,size+4);
+        x += size + 1;
+    }
     if ( KOPrefs::instance()->mMonthShowIcons ) {
         if ( mInfo ) { 
             p->fillRect ( x, y,size,size, Qt::darkGreen );
@@ -349,10 +375,24 @@ void MonthViewItem::paint(QPainter *p)
             x += size + 1;
         }
     }
+
+
+   
+
+    if ( sel ) p->setPen( Qt::white );
+    else p->setPen( palette().color( QPalette::Normal,QColorGroup::Foreground ) ); 
+
+#if 0
+        p->setPen( palette().color( QPalette::Normal, sel ?                 \
+                               QColorGroup::HighlightedText : QColorGroup::Foreground ) ); 
+#endif
+    QColor textColor = p->pen().color();
+
+
     if ( mMultiday ) { 
         int yyy = y+(size/2);
         int sizeM = size+2;
-        p->setBrush( QBrush::SolidPattern );
+        p->setBrush( QBrush( textColor ) );
         p->drawLine ( x+1, yyy, x +sizeM +sizeM/2-1, yyy ) ;
         if ( mMultiday == 2 || mMultiday == 3 ) { 
             QPointArray pa ( 3 );
@@ -370,7 +410,6 @@ void MonthViewItem::paint(QPainter *p)
         }
         if ( mMultiday == 1 ) {  
             // p->fillRect (  x, yyy-sizeM/2+1, sizeM/2, size, QBrush ( QBrush::SolidPattern   ) );
-           
             p->drawLine (  x+1, yyy-sizeM/2,  x+1, yyy+sizeM/2 );
         }
         if (  mMultiday == 3 ) { 
@@ -382,7 +421,7 @@ void MonthViewItem::paint(QPainter *p)
         x += sizeM + 1;
     }
 
-    if ( mIncidence->type() == "Todo" ){
+    if ( mIncidence->typeID() == todoID ){
         Todo* td = ( Todo* ) mIncidence;
         if ( td->isCompleted() ) {
             int half = size/2;
@@ -392,7 +431,7 @@ void MonthViewItem::paint(QPainter *p)
 
         } else {
             int val = td->percentComplete()/20;
-            p->fillRect ( x+1, y-2, val ,size+4,Qt::black );
+            p->fillRect ( x+1, y-2, val ,size+4,textColor );
             p->drawRect ( x, y-2,7,size+4);
             x += size + 3;
         }
@@ -404,8 +443,7 @@ void MonthViewItem::paint(QPainter *p)
         yPos = fm.ascent() + fm.leading()/2;
     else
         yPos = pmheight/2 - fm.height()/2  + fm.ascent();
-    p->setPen( palette().color( QPalette::Normal, sel ? \
-                                QColorGroup::HighlightedText : QColorGroup::Foreground ) );
+  
     if ( KOPrefs::instance()->mMonthShowTimes || isWeekItem) {
         p->drawText( x, yPos, text() );
         if ( mIncidence->cancelled() ) {
@@ -597,6 +635,7 @@ void MonthViewCell::setHoliday( const QString &holiday )
 
 void MonthViewCell::startUpdateCell()
 {
+    blockSignals( true );
     mdayCount = 0;
     setFocusPolicy(NoFocus); 
     if ( !mMonthView->isUpdatePossible() )
@@ -610,6 +649,7 @@ void MonthViewCell::startUpdateCell()
         mAvailItemList.setAutoDelete( true );
         mAvailItemList.clear();
         mAvailItemList.setAutoDelete( false );
+        clear();
     }
    
     setPrimary( mDate.month()%2 );
@@ -623,6 +663,8 @@ void MonthViewCell::startUpdateCell()
     //clear(); 
     while ( CurrentAvailItem ) {
             MonthViewItem *item = CurrentAvailItem;
+            //item->setHighlightedFalse();
+            item->recycle( 0, "");
             CurrentAvailItem = (MonthViewItem *)item->next();
             mAvailItemList.append( item ); 
             takeItem ( item );
@@ -718,9 +760,9 @@ int MonthViewCell::insertEvent(Event *event)
         if ( mAvailItemList.count() ) {
             item = mAvailItemList.first();
             mAvailItemList.remove( item );
-            item->recycle( event, mDate, text );
+            item->recycle( event, text );
         } else {
-            item = new MonthViewItem( event, mDate, text );
+            item = new MonthViewItem( event, text );
         }
         
         QPalette pal;
@@ -730,14 +772,16 @@ int MonthViewCell::insertEvent(Event *event)
             if ( KOPrefs::instance()->mMonthViewUsesForegroundColor ) {
                 pal = getPalette();
                 if (cat.isEmpty()) {
-                    pal.setColor(QColorGroup::Foreground,KOPrefs::instance()->mEventColor);
+                    //pal.setColor(QColorGroup::Foreground,KOPrefs::instance()->mEventColor);
+                    pal.setColor(QColorGroup::Foreground,KOPrefs::instance()->defaultColor( event->calID() ));
                 } else {
                     pal.setColor(QColorGroup::Foreground, *(KOPrefs::instance()->categoryColor(cat)));
                 }
 
             } else {
                 if (cat.isEmpty()) {
-                    pal = QPalette(KOPrefs::instance()->mEventColor, KOPrefs::instance()->mEventColor);
+                    //pal = QPalette(KOPrefs::instance()->mEventColor, KOPrefs::instance()->mEventColor);
+                    pal = QPalette( KOPrefs::instance()->defaultColor( event->calID() ), KOPrefs::instance()->defaultColor( event->calID() ));
                 } else {
                     pal = QPalette(*(KOPrefs::instance()->categoryColor(cat)), *(KOPrefs::instance()->categoryColor(cat)));
                 } 
@@ -746,9 +790,10 @@ int MonthViewCell::insertEvent(Event *event)
         } else {
             pal = mStandardPalette ;
         }
+        pal.setColor(QColorGroup::Highlight, KOPrefs::instance()->mHighlightColor);
         item->setPalette( pal );
-        item->setRecur( event->recurrence()->doesRecur() );
-        item->setAlarm( event->isAlarmEnabled() && multiday < 2 );
+        item->setRecur( event->doesRecur() );
+        item->setAlarm( event->isAlarmEnabled() && multiday < 2 && event->alarmEnabled() );
         item->setMoreInfo( event->description().length() > 0  );
 #ifdef DESKTOP_VERSION
         Attendee *me = event->attendeeByMails(KOPrefs::instance()->mAdditionalMails,
@@ -761,14 +806,21 @@ int MonthViewCell::insertEvent(Event *event)
         } else
             item->setReply(false);
 #endif
+       
         item->setMultiDay( multiday );
         if ( multiday ) {
             insertItem( item ,mdayCount);
             ++mdayCount;
         } else {
-            uint i;
-            int pos = mdayCount;
-            for ( i = mdayCount; i < count();++i ) {
+            uint i = mdayCount;
+            uint pos = mdayCount;
+            uint itcount = count();
+            if ( itcount > 1000 ) {
+                qDebug("KO: Bug in MonthViewCell::insertEvent %u ", itcount);
+                itcount = 0;
+            }
+            for ( i = pos; i < itcount;++i ) {
+                // qDebug("i %d mday %u count %d ",i,itcount,mdayCount );
                 QListBoxItem* it = this->item ( i );
                 if ( it && text < it->text() ) {
                     pos = i;
@@ -798,9 +850,9 @@ void MonthViewCell::insertTodo(Todo *todo)
         if ( mAvailItemList.count() ) {
             item = mAvailItemList.first();
             mAvailItemList.remove( item );
-            item->recycle( todo, mDate, text );
+            item->recycle( todo, text );
         } else {
-            item = new MonthViewItem( todo, mDate, text );
+            item = new MonthViewItem( todo, text );
         }
         //MonthViewItem *item = new MonthViewItem( todo, mDate, text );
         //item->setPalette( mStandardPalette );
@@ -811,14 +863,16 @@ void MonthViewCell::insertTodo(Todo *todo)
             if ( KOPrefs::instance()->mMonthViewUsesForegroundColor ) {
                 pal = getPalette();
                 if (cat.isEmpty()) {
-                    pal.setColor(QColorGroup::Foreground,KOPrefs::instance()->mEventColor);
+                    //pal.setColor(QColorGroup::Foreground,KOPrefs::instance()->mEventColor);
+                    pal.setColor(QColorGroup::Foreground,KOPrefs::instance()->defaultColor( todo->calID() ));
                 } else {
                     pal.setColor(QColorGroup::Foreground, *(KOPrefs::instance()->categoryColor(cat)));
                 }
 
             } else {
                 if (cat.isEmpty()) {
-                    pal = QPalette(KOPrefs::instance()->mEventColor, KOPrefs::instance()->mEventColor);
+                    //pal = QPalette(KOPrefs::instance()->mEventColor, KOPrefs::instance()->mEventColor);
+                    pal = QPalette(KOPrefs::instance()->defaultColor( todo->calID() ), KOPrefs::instance()->defaultColor( todo->calID() ));
                 } else {
                     pal = QPalette(*(KOPrefs::instance()->categoryColor(cat)), *(KOPrefs::instance()->categoryColor(cat)));
                 } 
@@ -827,9 +881,10 @@ void MonthViewCell::insertTodo(Todo *todo)
         } else {
             pal = mStandardPalette ;
         }
+        pal.setColor(QColorGroup::Highlight, KOPrefs::instance()->mHighlightColor);
         item->setPalette( pal );
-        item->setRecur( todo->recurrence()->doesRecur() );
-        item->setAlarm( todo->isAlarmEnabled() );
+        item->setRecur( todo->doesRecur() );
+        item->setAlarm( todo->isAlarmEnabled() && todo->alarmEnabled() );
         item->setMoreInfo( todo->description().length() > 0  );
         insertItem( item , count());
 #ifdef DESKTOP_VERSION
@@ -844,6 +899,7 @@ void MonthViewCell::repaintfinishUpdateCell()
         updateItem ( mitem );
         mitem = (MonthViewItem *)mitem->next();
     }
+    blockSignals( false );
 }
 void MonthViewCell::finishUpdateCell()
 {
@@ -966,13 +1022,7 @@ QDate MonthViewCell::selectedIncidenceDate()
     QDate qd;
     int index = currentItem();
     if ( index < 0 ) return qd;
-  
-    MonthViewItem *mitem =
-        static_cast<MonthViewItem *>( item( index ) );
-
-    if ( !mitem ) return qd;
-  
-    return mitem->incidenceDate();
+    return mDate;
 }
 
 void MonthViewCell::deselect()
@@ -995,15 +1045,14 @@ void MonthViewCell::resizeEvent ( QResizeEvent * e )
     mLabel->setMaximumHeight( height() - lineWidth()*2 );
     
     QString text;
-    mLabel->setText( text );
+    //mLabel->setText( text );
     bool smallDisplay = QApplication::desktop()->width() < 320 && KOPrefs::instance()->mMonthViewSatSunTog;
     if ( KOPrefs::instance()->mMonthViewWeek || KOGlobals::self()->calendarSystem()->day( mDate ) == 1 || (mDate.dayOfWeek() == 7 && !smallDisplay ) || KOPrefs::instance()->mMonthShowShort) { 
-        text = KOGlobals::self()->calendarSystem()->monthName( mDate, true ) + " ";
+        text = KOGlobals::self()->calendarSystem()->monthName( mDate, true ) + " " + QString::number( mDate.day() );
         mLabel->resize( mLabelBigSize  );
-        text += QString::number( KOGlobals::self()->calendarSystem()->day(mDate) );
     } else {
         mLabel->resize( mLabelSize );
-        text += QString::number( KOGlobals::self()->calendarSystem()->day(mDate) );
+        text = QString::number( mDate.day() );
     }
     mLabel->setText( text );
 
@@ -1061,19 +1110,51 @@ void MonthViewCell::contextMenu( QListBoxItem *item )
         mMonthView->showContextMenu( 0 );
         return;
     }
+    //selection( item );
+    //qApp->processEvents();
     MonthViewItem *eventItem = static_cast<MonthViewItem *>( item );
     Incidence *incidence = eventItem->incidence();
-    if ( incidence ) mMonthView->showContextMenu( incidence );
+    if ( incidence ) {
+      mBlockDeselect = true;
+        mMonthView->showContextMenu( incidence );
+    }
 }
 
 void MonthViewCell::selection( QListBoxItem *item )
 {
-    if ( !item ) return;
-
+    if ( !item ) {
+        emit highlightIncidence( 0 , this, 0 );
+        return;
+    }
+    MonthViewItem * it = (static_cast<MonthViewItem *>( item ));
+    emit highlightIncidence( it->incidence(), this, it->multiDay() );
     mMonthView->setSelectedCell( this );
 }
 
-
+void  MonthViewCell::deHighLight()
+{
+    MonthViewItem *mitem = (MonthViewItem*) firstItem ();
+    while ( mitem ) {
+        if ( mitem->setHighlightedFalse() )
+            updateItem ( mitem );
+        mitem = (MonthViewItem *)mitem->next();
+    }
+}
+// returns true if no inc found
+bool MonthViewCell::doHighLight( Incidence * inc )
+{
+ 
+    MonthViewItem *mitem = (MonthViewItem*) firstItem ();
+    while ( mitem ) {
+        if ( mitem->incidence() == inc ) {
+            if ( mitem->setHighlighted( inc ) )
+                updateItem ( mitem );
+            return false;
+        }
+        mitem = (MonthViewItem *)mitem->next();
+    }
+    return true;
+}    
 // *******************************************************************************
 // *******************************************************************************
 // *******************************************************************************
@@ -1185,6 +1266,8 @@ KOMonthView::KOMonthView(Calendar *calendar, QWidget *parent, const char *name)
                      SLOT( nextCell() ) );
             connect( cell, SIGNAL( prevCell() ),
                      SLOT( prevCell() ) );
+            connect( cell, SIGNAL(  highlightIncidence( Incidence * , MonthViewCell *, int ) ),
+                     SLOT( incidenceHighlighted( Incidence *, MonthViewCell *, int ) ));
         }
     }
     mCellsW.resize( mDaysPerWeek );
@@ -1202,6 +1285,8 @@ KOMonthView::KOMonthView(Calendar *calendar, QWidget *parent, const char *name)
                  SLOT( nextCell() ) );
         connect( cell, SIGNAL( prevCell() ),
                  SLOT( prevCell() ) );
+        connect( cell, SIGNAL(  highlightIncidence( Incidence * , MonthViewCell *, int ) ),
+                 SLOT( incidenceHighlighted( Incidence *, MonthViewCell *, int ) ));
         cell->updateConfig(KOPrefs::instance()->mMonthViewUsesBigFont );
     }
 
@@ -1217,6 +1302,8 @@ KOMonthView::KOMonthView(Calendar *calendar, QWidget *parent, const char *name)
                                   i18n("Journal"),this,
                                   SLOT(slotEditJournal()),false);
 
+    connect (mContextMenu ,SIGNAL(categoryChanged( Incidence * )),this,
+                     SLOT( catChanged( Incidence * ) ));
 
 
     QString pathString = "";
@@ -1273,6 +1360,86 @@ KOMonthView::~KOMonthView()
     delete mContextMenu;
 }
 
+void KOMonthView::catChanged( Incidence * )
+{
+    updateView();
+}
+void KOMonthView::incidenceHighlighted( Incidence * inc , MonthViewCell* mc, int mday )
+{
+    static Incidence * lastInc = 0;
+    static MonthViewCell * lastCell = 0;
+    
+    if ( lastInc == inc && lastCell == mc )
+        return;
+    lastInc = inc;
+    lastCell = mc;
+    //qDebug("KOMonthView::incidenceHighlighted %d %d %d", inc, mc, mday );
+
+    bool weekview = false;
+    uint index = 0;
+    for (uint i = 0; i < mCellsW.count(); ++i) {
+        if ( mCellsW[i] == mc ) {
+            weekview = true;
+            index = i;
+            break;
+        }
+    }
+    QPtrVector<MonthViewCell> *cells;
+    if ( weekview ) 
+        cells = &mCellsW;
+    else {
+        for (uint i = 0; i < mCells.count(); ++i) {
+            if ( mCells[i] == mc ) {
+                index = i;
+                break;
+            }
+        }
+        cells = &mCells;
+    }
+    for (uint i = 0; i < (*cells).count(); ++i) {
+        (*cells)[i]->deHighLight();
+    }
+    if ( ! inc ) 
+        return;
+    
+    uint count = (*cells).count();
+    bool goLeft = (mday > 1 && index > 0);
+    bool goRight = (mday < 3 && mday > 0 && index < count -1);
+    for (uint iii = 1; iii < count; ++iii) {
+        if ( goLeft ) {
+            int left = index - iii;
+            if ( left >= 0 ) {
+                if ( (*cells)[(uint)left]->doHighLight(inc) )
+                    goLeft = false;
+            } else 
+                goLeft = false;
+        } 
+        if ( goRight ) {
+            uint right = index + iii;
+            if ( right < count ) {
+                if ( (*cells)[right]->doHighLight(inc) )
+                    goRight = false; 
+
+            } else  
+                goRight = false; 
+        }
+
+    }
+#if 0
+    if ( mday > 1 && index > 0 )
+        for (int i = index-1; i >= 0; --i) {
+            //qDebug("index %d iii %d ", index, i);
+            if ( (*cells)[(uint)i]->doHighLight(inc) )
+                break;
+        }
+    if ( mday < 3 && mday > 0 && index < (*cells).count()-1)
+        for (uint i = index+1; i < (*cells).count(); ++i) {
+            if ( (*cells)[i]->doHighLight(inc) )
+                break;
+        }
+#endif
+    
+}
 void KOMonthView::selectInternalWeekNum ( int n )
 {
     switchView();  
@@ -1338,7 +1505,7 @@ DateList KOMonthView::selectedDates()
 
     return selected;
 }
-
+#if 0
 void KOMonthView::printPreview(CalPrinter *calPrinter, const QDate &fd,
                                const QDate &td)
 {
@@ -1346,7 +1513,7 @@ void KOMonthView::printPreview(CalPrinter *calPrinter, const QDate &fd,
     calPrinter->preview(CalPrinter::Month, fd, td);
 #endif
 }
-
+#endif
 void KOMonthView::updateConfig()
 {
  
@@ -1367,7 +1534,8 @@ void KOMonthView::updateConfig()
     if ( !  mShowWeekView ) {
         if ( temp != KOPrefs::instance()->mMonthViewSatSunTog )
             computeLayout();
-    }
+    } else 
+        doComputeLayoutWeek();
     updateDayLabels();
     //qDebug("KOMonthView::updateConfig() %d %d %d ",height(), mDayLabels[0]->sizeHint().height() ,mNumWeeks);
     //int cellHeight = (height() - mDayLabels[0]->sizeHint().height()) /mNumWeeks;
@@ -1432,7 +1600,7 @@ void KOMonthView::showDates(const QDate &start, const QDate &)
     QPtrVector<MonthViewCell> *cells;
     QPtrVector<QLabel> *dayLabels;
     QPtrVector<KOWeekButton> *weekLabels;
-    int weekNum = 6;
+    uint weekNum = 6;
     mStartDate = start;
     if ( mShowWeekView ) {
         weekNum = 1;
@@ -1458,7 +1626,6 @@ void KOMonthView::showDates(const QDate &start, const QDate &)
     while( KOGlobals::self()->calendarSystem()->dayOfWeek(mStartDate) != startWeekDay ) {
         mStartDate = mStartDate.addDays( -1 );
     }
-    bool primary = false;
     uint i;
     for( i = 0; i < (*cells).size(); ++i ) {
         QDate date = mStartDate.addDays( i );
@@ -1528,7 +1695,6 @@ void KOMonthView::updateView()
     QPtrList<Event> events = calendar()->events();
     Event *event;
     QDateTime dt;
-    bool ok;
     QDate endDate =  mStartDate.addDays( timeSpan );
     for( event = events.first(); event; event = events.next() ) { // for event
         if ( event->doesRecur() ) {
@@ -1608,7 +1774,8 @@ void KOMonthView::updateView()
     processSelectionChange();
     //qApp->processEvents();
      for( i = 0; i < timeSpan+1; ++i ) {
-         (*cells)[i]->repaintfinishUpdateCell();
+         //(*cells)[i]->repaintfinishUpdateCell();
+         QTimer::singleShot( 0, (*cells)[i], SLOT ( repaintfinishUpdateCell() ) );
     }
      setKeyBFocus();
 #else
@@ -1640,13 +1807,15 @@ void KOMonthView::setKeyBoardFocus()
         shootAgain = !mWeekLabels[mNumWeeks]->hasFocus();
          mWeekLabels[mNumWeeks]->setFocus();
     }
-    if ( shootAgain ) {
-      QTimer::singleShot( 0, this, SLOT ( setKeyBFocus() ) );
+    --mKBFcounter;
+    if ( shootAgain && mKBFcounter > 0 ) {
+      QTimer::singleShot( 50, this, SLOT ( setKeyBoardFocus() ) );
     }
 }
 void KOMonthView::setKeyBFocus()
 {
     //qDebug("KOMonthView::setKeyBFocus() ");
+    mKBFcounter = 10;
     QTimer::singleShot( 0, this, SLOT ( setKeyBoardFocus() ) );
 }
 void KOMonthView::resizeEvent(QResizeEvent * e)
@@ -1657,6 +1826,8 @@ void KOMonthView::resizeEvent(QResizeEvent * e)
         slotComputeLayout();
     } else
         mComputeLayoutTimer->start( 100 );
+    if ( e )
+        KOEventView::resizeEvent( e );
 }
 
 void KOMonthView::slotComputeLayout()
@@ -1664,40 +1835,33 @@ void KOMonthView::slotComputeLayout()
     mComputeLayoutTimer->stop();
     //qDebug("KOMonthView::Post - resizeEvent %d %d ", width(), height() );
     computeLayout();
-    clPending = true;  
+    clPending = true;
     setKeyBFocus();
 }
-void KOMonthView::computeLayoutWeek()
+
+void KOMonthView::doComputeLayoutWeek()
 {
-    static int lastWid = 0;
-    static int lastHei = 0;
+
     int daysToShow;
     bool combinedSatSun  = false;
     if (mShowSatSunComp = KOPrefs::instance()->mMonthViewSatSunTog ) {
         daysToShow = 6;
         combinedSatSun  = true;
     }
-    int tWid = topLevelWidget()->size().width();
-    int tHei = topLevelWidget()->size().height();
-
     int wid = width();//e
     int hei = height()-1-mNavigatorBar->height();
-
-    if ( ((wid *3)/2) < tWid && (( hei *3) /2) < tHei  ) 
-        return;
-     
-    if ( lastWid == width() && lastHei == height() ) {
-        //qDebug("KOListWeekView::No compute layout needed ");
-        return;
-    }
-    lastWid = width();
-    lastHei = height();
-
-
-    if ( wid < hei )
+#ifdef DESKTOP_VERSION
+    if ( !KOPrefs::instance()->mMonthViewWeekRowlayout ) {
         daysToShow = 2;
-    else
-        daysToShow = 3;
+    } else 
+#endif
+        {
+        if ( wid < hei + 40 )
+            daysToShow = 2;
+        else
+            daysToShow = 3;
+    }
+    bool landscape = (daysToShow == 3);
     mShowSatSunComp = true;
     combinedSatSun  = true;
         
@@ -1707,7 +1871,6 @@ void KOMonthView::computeLayoutWeek()
     wid -= weeklabelwid;
 
     int colWid = wid / daysToShow;
-    int lastCol = wid - ( colWid*6  ); 
     int dayLabelHei = mDayLabelsW[0]->sizeHint().height();
     int cellHei = (hei - (5- daysToShow )*dayLabelHei) /(5- daysToShow ); 
     int colModulo = wid % daysToShow;
@@ -1728,12 +1891,19 @@ void KOMonthView::computeLayoutWeek()
         if ( ((i) % daysToShow) >= daysToShow-colModulo ) {
             ++w;
         }
+        int xC,yC,wC,hC;
         if ( i >=  5 ) { 
             int wi = width() -  x - weeklabelwid;
             if ( i == 5 ) { 
-                mDayLabelsW[i]->setGeometry( x+weeklabelwid,y,wi/2+wi%2,h);
+                xC = x+weeklabelwid;
+                yC = y;
+                wC = wi/2+wi%2;
+                hC = h;
             } else {
-                mDayLabelsW[i]->setGeometry( x+weeklabelwid,y,wi,h);
+                xC = x+weeklabelwid;
+                yC = y;
+                wC = wi;
+                hC = h;
             }
             x = x - w +  wi - (wi/2 );
         }
@@ -1742,8 +1912,14 @@ void KOMonthView::computeLayoutWeek()
             if ( !(( i+1) % daysToShow)) {
                 wi = width() -  x - weeklabelwid;
             }
-            mDayLabelsW[i]->setGeometry( x+weeklabelwid,y,wi,h);
+            xC = x+weeklabelwid;
+            yC = y;
+            wC = wi;
+            hC = h;
         }
+        mDayLabelsW[mapWeekLayout(i,landscape)]->setGeometry( xC,yC,wC,hC);
+
+
         x += w;                                   
     }
     x= 0;
@@ -1751,7 +1927,8 @@ void KOMonthView::computeLayoutWeek()
     w = colWid;
     h = cellHei;
     int max = 0;
-    for ( i = 0; i < mCellsW.count(); ++i) {
+    int w_count = mCellsW.count();
+    for ( i = 0; i < w_count; ++i) {
         if ( i > 6 ) {
             mCellsW[i]->hide();
             continue;
@@ -1764,23 +1941,34 @@ void KOMonthView::computeLayoutWeek()
         if ( i  == (daysToShow-1-rowModulo)*7)
             ++h; 
       
+        int xC,yC,wC,hC;
         if ( i >= 5 ) {
             if ( i ==5 ) {
                 max = h/2;
-                mCellsW[i]->setGeometry ( x+weeklabelwid,y,w,max ); 
+                xC = x+weeklabelwid;
+                yC = y;
+                wC = w;
+                hC = max;
                 x -= w ;y += h/2;
             } else {
                 if ( ((i-1) % daysToShow) >= daysToShow-colModulo ) {
                     ++w;
                 }
                 max = h-h/2;
-                mCellsW[i]->setGeometry ( x+weeklabelwid,y,w,max ); 
+                xC = x+weeklabelwid;
+                yC = y;
+                wC = w;
+                hC = max;
                 y -= h/2;
             }
         } else {
             max = h;
-            mCellsW[i]->setGeometry ( x+weeklabelwid,y,w,h ); 
+            xC = x+weeklabelwid;
+            yC = y;
+            wC = w;
+            hC = h;
         }
+        mCellsW[mapWeekLayout(i,landscape)]->setGeometry ( xC,yC,wC,hC ); 
                 
        
         x += w;
@@ -1804,6 +1992,56 @@ void KOMonthView::computeLayoutWeek()
     //if ( forceUpdate )
     //  updateView();
 }
+void KOMonthView::computeLayoutWeek()
+{
+    static int lastWid = 0;
+    static int lastHei = 0;
+    int tWid = topLevelWidget()->size().width();
+    int tHei = topLevelWidget()->size().height();
+    int wid = width();//e
+    int hei = height()-1-mNavigatorBar->height();
+    if ( ((wid *3)/2) < tWid && (( hei *3) /2) < tHei  ) 
+        return;
+
+    if ( lastWid == width() && lastHei == height() ) {
+        //qDebug("KOListWeekView::No compute layout needed ");
+        return;
+    }
+    lastWid = width();
+    lastHei = height();
+    doComputeLayoutWeek();
+}
+int KOMonthView::mapWeekLayout( int  index, bool landscape )
+{
+    if ( KOPrefs::instance()->mMonthViewWeekRowlayout )
+        return index;
+    int diff = 0;
+    if ( !landscape ) diff = 1;
+     switch( index ) {
+     case 0: 
+     case 5: 
+     case 6: 
+         return index;
+         break;
+     case 1: 
+         return 2+diff;
+         break;
+     case 2: 
+         return 4-(3*diff);
+         break;
+     case 3: 
+         return 1+(3*diff);
+         break;
+     case 4:
+         return 3-diff; 
+         break;
+     default:
+         qDebug("KO: Error in mapping week layout ");
+         return index;
+         break;
+     }
+     return index;
+}
 void KOMonthView::computeLayout()
 {
   
@@ -1843,7 +2081,6 @@ void KOMonthView::computeLayout()
     wid -= weeklabelwid;
 
     int colWid = wid / daysToShow;
-    int lastCol = wid - ( colWid*6  ); 
     int dayLabelHei = mDayLabels[0]->sizeHint().height();
     int cellHei = (hei - dayLabelHei) /6; 
     int colModulo = wid % daysToShow;
@@ -1878,7 +2115,8 @@ void KOMonthView::computeLayout()
     w = colWid;
     h = cellHei ;
     int max = 0;
-    for ( i = 0; i < mCells.count(); ++i) {
+    int mc_count = mCells.count();
+    for ( i = 0; i < mc_count; ++i) {
         //qDebug("iii %d ", i);
         w = colWid;
         if ( ((i) % 7) >= 7-colModulo ) {
@@ -1943,7 +2181,7 @@ void KOMonthView::showContextMenu( Incidence *incidence )
         mNewItemMenu->popup(QCursor::pos());
     }
     /*
-      if( incidence && incidence->type() == "Event" ) {
+      if( incidence && incidence->typeID() == eventID ) {
       Event *event = static_cast<Event *>(incidence);
       mContextMenu->showEventPopup(event);
       } else {
@@ -2056,7 +2294,7 @@ void KOMonthView::keyPressEvent ( QKeyEvent * e )
 
 void KOMonthView::nextCell()
 {
-   bool res =  focusNextPrevChild ( true ); 
+   focusNextPrevChild ( true ); 
 }
 void KOMonthView::prevCell()
 {
