@@ -230,12 +230,22 @@ KOPrefs::KOPrefs() :
   addItemBool("UseAppColors",&mUseAppColors,false); 
 
   
-
+  KPrefs::setCurrentGroup("Conflicts");
+  addItemBool("EnableAutoDetect",&mDetectConflicts,true);
+  addItemBool("CheckConflictsFree",&mIncludeFree,true);
+  addItemBool("CheckConflictsAllDayAllDay",&mCheckConflictsAllDayAllDay,false);
+  addItemBool("CheckConflictsAllDayNonAD",&mCheckConflictsAllDayNonAD,false);
+  addItemBool("CheckConflictsNonADAllDay",&mCheckConflictsNonADAllDay,false);
+  addItemBool("CheckConflictsNonADNonAD",&mCheckConflictsNonADNonAD,true);
+  addItemString("FilterConflictEditItem", &mFilterConflictEditItem ,"nofilter" );
+  addItemString("FilterConflictAllItem", &mFilterConflictAllItem ,"nofilter" );
+  
   KPrefs::setCurrentGroup("Views");
   addItemBool("Block Popup Menu",&mBlockPopupMenu,false);
   addItemBool("Show Date Navigator",&mShowDateNavigator,true);
   addItemInt("Hour Size",&mHourSize,8);
   addItemBool("Show Daily Recurrences",&mDailyRecur,true);
+  addItemBool("ShowLongAllday",&mLongAllday,true);
   addItemBool("Show Weekly Recurrences",&mWeeklyRecur,true);
   addItemBool("Show Month Daily Recurrences",&mMonthDailyRecur,true);
   addItemBool("Show Month Weekly Recurrences",&mMonthWeeklyRecur,true);
@@ -449,7 +459,7 @@ void KOPrefs::usrReadConfig()
         KopiCalendarFile *kkf = getNewCalendar();
         kkf->isStandard = true;
         kkf->mName = i18n("Standard");
-        kkf->mFileName = locateLocal( "data", "korganizer/mycalendar.ics" );
+        kkf->mFileName = QDir::convertSeparators( locateLocal( "data", "korganizer/mycalendar.ics" ) );
     } 
     while ( mNextAvailableCalendar  <= numCals ) {
         //qDebug("Read cal #%d ",  mNextAvailableCalendar );
@@ -461,8 +471,8 @@ void KOPrefs::usrReadConfig()
         kkf->isAlarmEnabled = fc.readBoolEntry( prefix+"_isAlarmEnabled", true);
         kkf->isReadOnly = fc.readBoolEntry( prefix+"_isReadOnly", false);
         kkf->mName =  fc.readEntry( prefix+"_Name", "Calendar");
-        kkf->mFileName = fc.readEntry( prefix+"_FileName", kkf->mFileName);
-        kkf->mSavedFileName = fc.readEntry( prefix+"_SavedFileName", kkf->mFileName);
+        kkf->mFileName = QDir::convertSeparators( fc.readEntry( prefix+"_FileName", kkf->mFileName) );
+        kkf->mSavedFileName = QDir::convertSeparators( fc.readEntry( prefix+"_SavedFileName", kkf->mFileName) );
         kkf->mDefaultColor = fc.readColorEntry( prefix+"_Color",&mEventColor);
         if ( kkf->mCalNumber == 1 ) {
             kkf->mFileName = locateLocal( "data", "korganizer/mycalendar.ics" );
@@ -472,7 +482,7 @@ void KOPrefs::usrReadConfig()
             kkf->mFileName = locateLocal( "data", "korganizer/birthdays.ics" ); 
         }
         if ( kkf->isRelative )
-            kkf->mFileName = KGlobalSettings::calendarDir() + kkf->mSavedFileName;
+            kkf->mFileName = QDir::convertSeparators( KGlobalSettings::calendarDir() + kkf->mSavedFileName );
     }
 
     KPimPrefs::usrReadConfig();
