@@ -194,6 +194,7 @@ class KOPrefs : public KPimPrefs
     bool    mShowFullMenu;
     bool    mDailyRecur;
     bool    mWeeklyRecur;
+    bool    mLongAllday;
     bool    mMonthDailyRecur;
     bool    mMonthWeeklyRecur;
     bool    mMonthShowIcons;
@@ -349,6 +350,16 @@ class KOPrefs : public KPimPrefs
     int mNextAvailableCalendar;
     bool mGlobalUpdateDisabled;
 
+
+    bool mDetectConflicts;
+    bool mIncludeFree;
+    bool mCheckConflictsAllDayAllDay;
+    bool mCheckConflictsAllDayNonAD;
+    bool mCheckConflictsNonADAllDay;
+    bool mCheckConflictsNonADNonAD;
+    QString mFilterConflictEditItem;
+    QString mFilterConflictAllItem;
+
   private:
     QDict<QColor> mCategoryColors;
     QArray<KopiCalendarFile*> mDefCalColors;
