@@ -578,6 +578,11 @@ void KOPrefsDialog::setupViewsTab()
                &(KOPrefs::instance()->mWeeklyRecur),topFrame);
   topLayout->addWidget(weeklyRecur->checkBox(),ii++,0);
 
+  weeklyRecur =
+    addWidBool(i18n("Show multiday allday ev. in date nav."),
+               &(KOPrefs::instance()->mLongAllday),topFrame);
+  topLayout->addWidget(weeklyRecur->checkBox(),ii++,0);
+
 #ifdef DESKTOP_VERSION
   KPrefsDialogWidBool *enableToolTips =
       addWidBool(i18n("Enable tooltips displaying summary of ev."),
@@ -922,6 +927,45 @@ dummy =
                &(KOPrefs::instance()->mWTshowChanged),topFrame);
   topLayout->addWidget(dummy->checkBox(),ii++,0);
 
+  topFrame = addPage(i18n("Conflict detection"),0,0);
+
+  topLayout = new QGridLayout(topFrame,2,1);
+  topLayout->setSpacing(mSpacingHint);
+  topLayout->setMargin(mMarginHint);
+  ii = 0;  
+   dummy  = addWidBool(i18n("Enable conflict detection"),
+                       &(KOPrefs::instance()->mDetectConflicts),topFrame);
+  topLayout->addWidget(dummy->checkBox(), ii++,0);
+  topFrame = new QFrame( topFrame );
+  topLayout->addWidget(topFrame ,ii++,0);
+  topLayout = new QGridLayout(topFrame,4,1); 
+  connect ( dummy->checkBox(), SIGNAL( toggled( bool ) ), topFrame, SLOT ( setEnabled( bool ) ) );
+  dummy = addWidBool(i18n("Include events which \"show as free\""),
+                           &(KOPrefs::instance()->mIncludeFree),topFrame);
+  topLayout->addWidget(dummy->checkBox(), ii++,0);
+  topLayout->addWidget( new QLabel ( i18n("Conflict detection checks an <b>edited event</b> with <b>other events</b> for overlapping."), topFrame ) , ii++,0); 
+ 
+  topLayout->addWidget( new QLabel ( i18n("Filter for the edited event"), topFrame ) , ii++,0);
+  mFilterEditItem = new QComboBox(  topFrame );
+  topLayout->addWidget(mFilterEditItem,ii++,0);
+  topLayout->addWidget( new QLabel ( i18n("Filter for other events"), topFrame ) , ii++,0);
+  mFilterAllItem = new QComboBox( topFrame );
+  topLayout->addWidget(mFilterAllItem,ii++,0);
+  dummy = addWidBool(i18n("Check Allday with Allday"),
+                           &(KOPrefs::instance()->mCheckConflictsAllDayAllDay),topFrame);
+  topLayout->addWidget(dummy->checkBox(), ii++,0);
+  dummy = addWidBool(i18n("Check Allday with NonAllday"),
+                           &(KOPrefs::instance()->mCheckConflictsAllDayNonAD),topFrame);
+  topLayout->addWidget(dummy->checkBox(), ii++,0);
+  dummy = addWidBool(i18n("Check NonAllday with Allday"),
+                           &(KOPrefs::instance()->mCheckConflictsNonADAllDay),topFrame);
+  topLayout->addWidget(dummy->checkBox(), ii++,0);
+  dummy = addWidBool(i18n("Check NonAllday with NonAllday"),
+                           &(KOPrefs::instance()->mCheckConflictsNonADNonAD),topFrame);
+  topLayout->addWidget(dummy->checkBox(), ii++,0);
+
+
+
 
    topFrame = addPage(i18n("Alarm"),0,0);
     //  DesktopIcon("viewmag",KIcon::SizeMedium));
@@ -1435,6 +1479,20 @@ void KOPrefsDialog::usrReadConfig()
   mAlarmSuspendCount->setValue(KOPrefs::instance()->mAlarmSuspendCount );
   mAlarmBeepInterval->setValue(KOPrefs::instance()->mAlarmBeepInterval );
   mCatDefaultColor = KOPrefs::instance()->mEventColor;
+
+
+    KConfig cfgko(locateLocal("config","korganizerrc"));
+    cfgko.setGroup("General");
+    QStringList temp = cfgko.readListEntry("CalendarFilters");
+    temp.prepend(i18n("No Filter") );
+    mFilterEditItem->insertStringList( temp );
+    mFilterAllItem->insertStringList( temp );
+    int index = temp.findIndex( KOPrefs::instance()->mFilterConflictEditItem );
+    if ( index >= 0 )
+        mFilterEditItem->setCurrentItem( index );
+    index = temp.findIndex( KOPrefs::instance()->mFilterConflictAllItem );
+    if ( index >= 0 )
+        mFilterAllItem->setCurrentItem( index );
 }
 
 
@@ -1479,6 +1537,9 @@ void KOPrefsDialog::usrWriteConfig()
     KOPrefs::instance()->mAlarmSuspendTime = mAlarmSuspendTime->value() ;
     KOPrefs::instance()->mAlarmSuspendCount= mAlarmSuspendCount->value() ;
     KOPrefs::instance()->mAlarmBeepInterval= mAlarmBeepInterval->value() ;
+
+    KOPrefs::instance()->mFilterConflictEditItem = mFilterEditItem->currentText();
+    KOPrefs::instance()->mFilterConflictAllItem = mFilterAllItem->currentText();
 }
 
 void KOPrefsDialog::updateCategories()
