@@ -110,6 +110,7 @@ void KOViewManager::readSettings(KConfig *config)
     }
 }
 
+
 void KOViewManager::showDateView( int view, QDate date)
 {
     static int lastMode = 0;
@@ -282,6 +283,12 @@ void KOViewManager::resetDateSilent( QDate date , int days )
     mMainView->dateNavigator()->selectDates( date , days ); 
     mMainView->dateNavigator()->blockSignals( false );
 }
+void KOViewManager::setDefaultCalendar(int)
+{
+    if ( mJournalView && mCurrentView == mJournalView )
+        mJournalView->updateView();
+}
+
 void KOViewManager::showView(KOrg::BaseView *view, bool fullScreen )
 {
     if ( flagResetViewChangeDate < 10 )
@@ -448,6 +455,8 @@ void KOViewManager::showListView()
                  mMainView, SLOT ( moveIncidence( Incidence * ) ) );
         connect( mListView, SIGNAL( beamIncidenceSignal( Incidence *  ) ),
                  mMainView, SLOT ( beamIncidence( Incidence * ) ) );
+        connect( mListView, SIGNAL( beamIncidenceList( QPtrList<Incidence>  ) ),
+                 mMainView, SLOT ( beamIncidenceList( QPtrList<Incidence>  ) ) );
     }
     // bool temp = mFlagShowNextxDays;
     //globalFlagBlockPainting = true;
@@ -461,6 +470,7 @@ void KOViewManager::showListView()
     showView(mListView, KOPrefs::instance()->mFullViewTodo);
     //mFlagShowNextxDays = temp;
     KOPrefs::instance()->mCurrentDisplayedView = VIEW_L_VIEW;
+    mMainView->setScrollBarStep( 7 );
 }
 
 void KOViewManager::showAgendaView( bool fullScreen )
@@ -528,6 +538,7 @@ void KOViewManager::showAgendaView( bool fullScreen )
     KOPrefs::instance()->mCurrentDisplayedView = VIEW_A_VIEW;
     showView( mAgendaView, full);
     KOPrefs::instance()->mCurrentDisplayedView = VIEW_A_VIEW;
+    mMainView->setScrollBarStep( 1 );
 }
 
 void KOViewManager::showDayView()
@@ -595,6 +606,7 @@ void KOViewManager::showNextXView()
     mFlagShowNextxDays = true;
     mCurrentAgendaView = 3 ;
     KOPrefs::instance()->mCurrentDisplayedView = VIEW_NX_VIEW;
+    mMainView->setScrollBarStep( KOPrefs::instance()->mNextXDays );
 }
 bool KOViewManager::showsNextDays() 
 {
@@ -688,6 +700,7 @@ void KOViewManager::showMonthViewWeek()
     showView(mMonthView, full );
     mMonthView->setKeyBFocus();
     KOPrefs::instance()->mCurrentDisplayedView =  VIEW_ML_VIEW ;
+    mMainView->setScrollBarStep( 7 );
 }
 
 void KOViewManager::showMonth( const QDate & date )
@@ -720,6 +733,7 @@ void KOViewManager::showMonthView()
     showView(mMonthView, full );
     mMonthView->setKeyBFocus();
     KOPrefs::instance()->mCurrentDisplayedView =  VIEW_M_VIEW ;
+    mMainView->setScrollBarStep( 7 );
    
 }
 
@@ -777,6 +791,7 @@ void KOViewManager::showTodoView()
     globalFlagBlockAgenda = 1;
     showView( mTodoView, true );
     KOPrefs::instance()->mCurrentDisplayedView =  VIEW_T_VIEW ;
+    mMainView->setScrollBarStep( 7 );
 
 }
 
@@ -796,6 +811,7 @@ void KOViewManager::showJournalView()
     showView(mJournalView);
     mMainView->dateNavigator()->selectDates( 1 );
     KOPrefs::instance()->mCurrentDisplayedView = VIEW_J_VIEW  ;
+    mMainView->setScrollBarStep( 1 );
 }
 
 void KOViewManager::showTimeSpanView()
