@@ -89,13 +89,13 @@ int main( int argc, char **argv )
       MainWindow m;
 #ifndef DESKTOP_VERSION
      
-      QObject::connect( &a, SIGNAL (appMessage ( const QCString &, const QByteArray & )),&m, SLOT(recieve(  const QCString&, const QByteArray& )));
+      QObject::connect( &a, SIGNAL (appMessage ( const QCString &, const QByteArray & )),&m, SLOT(receiveStart(  const QCString&, const QByteArray& )));
       a.showMainWidget(&m );
 #else
       a.setMainWidget(&m );
       m.show();
       //m.resize( 800, 600 );
-      QObject::connect(&a, SIGNAL(lastWindowClosed()), &a, SLOT(quit()));
+      //QObject::connect(&a, SIGNAL(lastWindowClosed()), &a, SLOT(quit()));
 #endif
       if ( argc > 1 ) {
           QCString command = argv[1];
