@@ -50,7 +50,9 @@ class MainWindow : public QMainWindow
     virtual void showMaximized (); 
      void configureAgenda( int );
     void recieve( const QCString& msg, const QByteArray& data );
+    void receiveStart( const QCString& msg, const QByteArray& data );
  protected slots: 
+    void loadDataAfterStart();
     void calHint(); 
     void startMultiSync();
     void setCaptionToDates();
@@ -116,6 +118,10 @@ class MainWindow : public QMainWindow
     void enableIncidenceActions( bool );
     
   private:
+
+    QCString mCStringMess;
+    QByteArray mByteData;
+
     //void setMenuBar( QMenuBar * );
     bool mBRdisabled;
 #ifndef DESKTOP_VERSION
