@@ -25,12 +25,13 @@
 #include <qlayout.h>
 #include <qcheckbox.h>
 #include <qgroupbox.h>
+#include <qapplication.h>
 #include <qlabel.h>
 #include <qlistview.h>
 #include <qwhatsthis.h>
 #include <qlineedit.h>
 #include <qpushbutton.h>
-
+#include <qhbuttongroup.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
@@ -55,16 +56,40 @@ SearchDialog::SearchDialog(Calendar *calendar,CalendarView *parent)
     // Search expression
     QHBoxLayout *subLayout = new QHBoxLayout();
     layout->addLayout(subLayout);
+    /*
     searchLabel = new QLabel(topFrame);
     searchLabel->setText(i18n("Search for:"));
     subLayout->addWidget(searchLabel);
-
-    searchEdit = new KLineEdit(topFrame);
-    subLayout->addWidget(searchEdit);
-    QPushButton *OkButton = new QPushButton(  i18n("&Find"), topFrame );
+    */
+    QPushButton *OkButton = new QPushButton(  i18n("Search for:"), topFrame );
     //OkButton->setDefault( true );
     connect(OkButton,SIGNAL(clicked()),SLOT(doSearch()));
     subLayout->addWidget(OkButton);
+    searchEdit = new KLineEdit(topFrame);
+    subLayout->addWidget(searchEdit);
+
+    mAddItems = new QRadioButton( "+ ", topFrame );
+    mSubItems = new QRadioButton( "- ", topFrame );
+    mRefineItems = new QRadioButton( "< ", topFrame );
+    subLayout->addWidget( mAddItems );
+    subLayout->addWidget( mSubItems );
+    subLayout->addWidget( mRefineItems );
+    QFont fo ( mAddItems->font() );
+    fo.setBold( true );
+    fo.setPointSize( fo.pointSize() + 2 );
+    mAddItems->setFont( fo );
+    mSubItems->setFont( fo );
+    mRefineItems->setFont( fo );
+    connect( mAddItems  , SIGNAL( toggled ( bool ) ),this,SLOT(slot_add( bool )));
+    connect( mSubItems , SIGNAL( toggled ( bool ) ),this,SLOT(slot_sub( bool )));
+    connect( mRefineItems , SIGNAL( toggled ( bool ) ),this,SLOT(slot_refine( bool )));
+
+    QPushButton *togButton = new QPushButton( "", topFrame );
+    subLayout->addWidget(togButton);
+    connect(togButton,SIGNAL(clicked()),SLOT(toggleCheckboxes()));
+    togButton->setPixmap(SmallIcon("1updownarrow"));
+    togButton->setMinimumWidth( togButton->sizeHint().height() );
+
     searchEdit->setText("*"); // Find all events by default
     searchEdit->setFocus();
     connect(searchEdit, SIGNAL(textChanged ( const QString & )),this,SLOT(searchTextChanged( const QString & )));
@@ -73,7 +98,7 @@ SearchDialog::SearchDialog(Calendar *calendar,CalendarView *parent)
     // QGroupBox *subjectGroup = new QGroupBox(1,Vertical,i18n("Search In"),
     //                                        topFrame);
 
-    QHBox *incidenceGroup = new QHBox( topFrame );
+    incidenceGroup = new QHBox( topFrame );
     layout->addWidget(incidenceGroup);
 
     mSearchEvent = new QCheckBox(i18n("Events"),incidenceGroup);
@@ -81,7 +106,7 @@ SearchDialog::SearchDialog(Calendar *calendar,CalendarView *parent)
     mSearchTodo = new QCheckBox(i18n("Todos"),incidenceGroup);
     mSearchJournal = new QCheckBox(i18n("Journals"),incidenceGroup);
 
-    QHBox *subjectGroup = new QHBox( topFrame );
+    subjectGroup = new QHBox( topFrame );
     layout->addWidget(subjectGroup);
 
     mSummaryCheck = new QCheckBox(i18n("Summary/Loc."),subjectGroup);
@@ -89,7 +114,7 @@ SearchDialog::SearchDialog(Calendar *calendar,CalendarView *parent)
     mDescriptionCheck = new QCheckBox(i18n("Details"),subjectGroup);
     mCategoryCheck = new QCheckBox(i18n("Categories"),subjectGroup);
 
-    QHBox *attendeeGroup = new QHBox( topFrame );
+    attendeeGroup = new QHBox( topFrame );
     layout->addWidget(attendeeGroup );
     new QLabel( i18n("Attendee:"),attendeeGroup );
     mSearchAName = new QCheckBox(i18n("Name"),attendeeGroup  );
@@ -100,7 +125,9 @@ SearchDialog::SearchDialog(Calendar *calendar,CalendarView *parent)
     // layout->addWidget(rangeGroup);
 
     QWidget *rangeWidget = new QWidget(topFrame);
-    QHBoxLayout *rangeLayout = new QHBoxLayout(rangeWidget,0,KDialog::spacingHint());
+    int space = KDialog::spacingHint();
+    if ( QApplication::desktop()->width() <= 240 ) space = 1;
+    QHBoxLayout *rangeLayout = new QHBoxLayout(rangeWidget,0,space);
     rangeLayout->addWidget(new QLabel(i18n("From:"),rangeWidget));
     mStartDate = new KDateEdit(rangeWidget);
     rangeLayout->addWidget(mStartDate);
@@ -114,6 +141,7 @@ SearchDialog::SearchDialog(Calendar *calendar,CalendarView *parent)
     // Results list view
     listView = new KOListView(mCalendar,topFrame);
     layout->addWidget(listView);
+    listView->showCompletedTodos();
     //layout->setStretchFactor( listView, 333 );
     //listView->setSizePolicy( QSizePolicy(  QSizePolicy::Preferred  ,QSizePolicy::Expanding) );
     //listView->setMaximumHeight( 50 );
@@ -130,6 +158,45 @@ SearchDialog::SearchDialog(Calendar *calendar,CalendarView *parent)
 SearchDialog::~SearchDialog()
 {
   
+}
+void SearchDialog::slot_add( bool b )
+{
+    if ( b ) {
+        if ( mSubItems->isOn() ) mSubItems->toggle();
+        if ( mRefineItems->isOn() ) mRefineItems->toggle();
+        setCaption( i18n("Matching items will be added to list"));
+    } else
+        setCaption( i18n("List will be cleared before search"));
+}
+void SearchDialog::slot_sub( bool b)
+{
+  if ( b ) {
+        if ( mRefineItems->isOn() ) mRefineItems->toggle();
+        if ( mAddItems->isOn() ) mAddItems->toggle();
+        setCaption( i18n("Matching items will be removed from list"));
+    } else
+        setCaption( i18n("List will be cleared before search"));
+}
+void SearchDialog::slot_refine( bool b)
+{
+  if ( b ) {
+        if ( mSubItems->isOn() ) mSubItems->toggle();
+        if ( mAddItems->isOn() ) mAddItems->toggle();
+        setCaption( i18n("Search on displayed list only"));
+    } else
+        setCaption( i18n("List will be cleared before search"));
+}
+void SearchDialog::toggleCheckboxes()
+{
+    if ( incidenceGroup->isVisible() ) {
+        incidenceGroup->hide() ;
+        subjectGroup->hide() ;
+        attendeeGroup->hide() ;
+    } else {
+        incidenceGroup->show() ;
+        subjectGroup->show() ;
+        attendeeGroup->show() ;
+    }
 }
 void SearchDialog::raiseAndSelect()
 {
@@ -154,6 +221,9 @@ void SearchDialog::raiseAndSelect()
                 mSearchJournal->setChecked( true );
                 mSearchTodo->setChecked( false );
                 mSearchEvent->setChecked( false );
+                mSummaryCheck->setChecked( true ); 
+                mDescriptionCheck->setChecked( true ); 
+
             }
         }
         else if ( KOPrefs::instance()->mCurrentDisplayedView == VIEW_T_VIEW ) {
@@ -184,6 +254,10 @@ void SearchDialog::accept()
 }
 void SearchDialog::updateList()
 {
+    if ( KOPrefs::instance()->mGlobalUpdateDisabled ) {
+        listView->clear();
+        return;
+    }
     //listView->updateList();
     if ( isVisible() ) {
         updateView();
@@ -205,7 +279,6 @@ void SearchDialog::searchTextChanged( const QString &_text )
 void SearchDialog::doSearch()
 {
     QRegExp re;
-
     re.setWildcard(true); // most people understand these better.
     re.setCaseSensitive(false);
     QString st = searchEdit->text();
@@ -254,12 +327,11 @@ void SearchDialog::updateView()
     if ( st.right(1) != "*")
         st += "*";
     re.setPattern(st);
+    mMatchedEvents.clear();
+    mMatchedTodos.clear();
+    mMatchedJournals.clear();
     if (re.isValid()) {
         search(re);
-    } else {
-        mMatchedEvents.clear();
-        mMatchedTodos.clear();
-        mMatchedJournals.clear();
     }
     listView->setStartDate( mStartDate->date() );
     listView->showEvents(mMatchedEvents);
@@ -269,12 +341,18 @@ void SearchDialog::updateView()
 
 void SearchDialog::search(const QRegExp &re)
 {
-    QPtrList<Event> events = mCalendar->events( mStartDate->date(),
+    QPtrList<Event> events;
+    if ( !mAddItems->isChecked() && !mSubItems->isChecked() ) {
+        if ( mRefineItems->isChecked() ) events = mMatchedEvents;
+        mMatchedEvents.clear();
+    } 
+    if ( mSearchEvent->isChecked() ) {
+        if ( !mRefineItems->isChecked() )
+            events = mCalendar->events( mStartDate->date(),
                                                 mEndDate->date(),
                                                 false /*mInclusiveCheck->isChecked()*/ );
 
-    mMatchedEvents.clear();
-    if ( mSearchEvent->isChecked() ) {
+
         Event *ev;
         for(ev=events.first();ev;ev=events.next()) {
             if (mSummaryCheck->isChecked()) {
@@ -283,8 +361,13 @@ void SearchDialog::search(const QRegExp &re)
 #else
                     if (re.match(ev->summary()) != -1) 
 #endif
-                        {
-                            mMatchedEvents.append(ev);
+                        {   
+                            if ( mSubItems->isChecked() )
+                                mMatchedEvents.remove(ev);
+                            else {
+                                if ( !mMatchedEvents.contains( ev ) )
+                                    mMatchedEvents.append(ev);
+                            }
                             continue;
                         }
 #if QT_VERSION >= 0x030000
@@ -292,8 +375,13 @@ void SearchDialog::search(const QRegExp &re)
 #else
                     if (re.match(ev->location()) != -1) 
 #endif
-                        {
-                            mMatchedEvents.append(ev);
+                        {   
+                            if ( mSubItems->isChecked() )
+                                mMatchedEvents.remove(ev);
+                            else{
+                                if ( !mMatchedEvents.contains( ev ) )
+                                    mMatchedEvents.append(ev);
+                            }
                             continue;
                         }
             }
@@ -303,8 +391,13 @@ void SearchDialog::search(const QRegExp &re)
 #else
                     if (re.match(ev->description()) != -1) 
 #endif
-                        {    
-                            mMatchedEvents.append(ev);
+                        {       
+                            if ( mSubItems->isChecked() )
+                                mMatchedEvents.remove(ev);
+                            else{
+                                if ( !mMatchedEvents.contains( ev ) )
+                                    mMatchedEvents.append(ev);
+                            }
                             continue;
                         }
             }
@@ -315,7 +408,13 @@ void SearchDialog::search(const QRegExp &re)
                     if (re.match(ev->categoriesStr()) != -1) 
 #endif
                         {
-                            mMatchedEvents.append(ev);
+                                 
+                            if ( mSubItems->isChecked() )
+                                mMatchedEvents.remove(ev);
+                            else{
+                                if ( !mMatchedEvents.contains( ev ) )
+                                    mMatchedEvents.append(ev);
+                            }
                             continue;
                         }
             }
@@ -329,8 +428,13 @@ void SearchDialog::search(const QRegExp &re)
 #else
                             if (re.match(a->name()) != -1) 
 #endif
-                                {    
-                                    mMatchedEvents.append(ev);
+                                {       
+                                    if ( mSubItems->isChecked() )
+                                        mMatchedEvents.remove(ev);
+                                    else{
+                                        if ( !mMatchedEvents.contains( ev ) )
+                                            mMatchedEvents.append(ev);
+                                    }
                                     break;
                                 }
                     }
@@ -340,8 +444,13 @@ void SearchDialog::search(const QRegExp &re)
 #else
                             if (re.match(a->email()) != -1) 
 #endif
-                                {    
-                                    mMatchedEvents.append(ev);
+                                {     
+                                    if ( mSubItems->isChecked() )
+                                        mMatchedEvents.remove(ev);
+                                    else{
+                                        if ( !mMatchedEvents.contains( ev ) )
+                                            mMatchedEvents.append(ev);
+                                    }
                                     break;
                                 }
                     }
@@ -349,9 +458,15 @@ void SearchDialog::search(const QRegExp &re)
             }
         }
     }
-    QPtrList<Todo> todos = mCalendar->todos( );
-    mMatchedTodos.clear();
+    QPtrList<Todo> todos;
+
+    if ( !mAddItems->isChecked() && !mSubItems->isChecked() ) {
+        if ( mRefineItems->isChecked() ) todos = mMatchedTodos ;
+        mMatchedTodos.clear();
+    } 
+
     if ( mSearchTodo->isChecked() ) {
+        if ( !mRefineItems->isChecked() ) todos = mCalendar->todos( );
         Todo *tod;
         for(tod=todos.first();tod;tod=todos.next()) {
             if (mSummaryCheck->isChecked()) {
@@ -360,8 +475,11 @@ void SearchDialog::search(const QRegExp &re)
 #else
                     if (re.match(tod->summary()) != -1) 
 #endif
-                        {
-                            mMatchedTodos.append(tod);
+                        { 
+                            if ( mSubItems->isChecked() )
+                                mMatchedTodos.remove(tod);
+                            else if (!mMatchedTodos.contains( tod )) 
+                                mMatchedTodos.append(tod);
                             continue;
                         }
             }
@@ -371,8 +489,11 @@ void SearchDialog::search(const QRegExp &re)
 #else
                     if (re.match(tod->description()) != -1) 
 #endif
-                        {
-                            mMatchedTodos.append(tod);
+                        { 
+                            if ( mSubItems->isChecked() )
+                                mMatchedTodos.remove(tod);
+                            else if (!mMatchedTodos.contains( tod )) 
+                                mMatchedTodos.append(tod);
                             continue;
                         }
             }
@@ -382,8 +503,11 @@ void SearchDialog::search(const QRegExp &re)
 #else
                     if (re.match(tod->categoriesStr()) != -1) 
 #endif
-                        {                                 
-                            mMatchedTodos.append(tod);
+                        {    
+                            if ( mSubItems->isChecked() )
+                                mMatchedTodos.remove(tod);
+                            else if (!mMatchedTodos.contains( tod )) 
+                                mMatchedTodos.append(tod);                              
                             continue;
                         }
             }
@@ -397,8 +521,11 @@ void SearchDialog::search(const QRegExp &re)
 #else
                             if (re.match(a->name()) != -1) 
 #endif
-                                {    
-                                    mMatchedTodos.append(tod);
+                                {     
+                                    if ( mSubItems->isChecked() )
+                                        mMatchedTodos.remove(tod);
+                                    else if (!mMatchedTodos.contains( tod )) 
+                                        mMatchedTodos.append(tod);
                                     break;
                                 }
                     }
@@ -409,7 +536,10 @@ void SearchDialog::search(const QRegExp &re)
                             if (re.match(a->email()) != -1) 
 #endif
                                 {    
-                                    mMatchedTodos.append(tod);
+                                    if ( mSubItems->isChecked() )
+                                        mMatchedTodos.remove(tod);
+                                    else if (!mMatchedTodos.contains( tod )) 
+                                        mMatchedTodos.append(tod);
                                     break;
                                 }
                     }
@@ -417,27 +547,57 @@ void SearchDialog::search(const QRegExp &re)
             }
         }
     }
-    mMatchedJournals.clear();
+
+    QPtrList<Journal> journals;
+    if ( !mAddItems->isChecked() && !mSubItems->isChecked() ) {
+        if ( mRefineItems->isChecked() ) journals = mMatchedJournals ;
+        mMatchedJournals.clear();
+    } 
     if (mSearchJournal->isChecked() ) {
-        QPtrList<Journal> journals = mCalendar->journals( );
+        if ( ! mRefineItems->isChecked() ) journals = mCalendar->journals();
         Journal* journ;
         
         for(journ=journals.first();journ;journ=journals.next()) {
             if ( journ->dtStart().date() <= mEndDate->date() 
                  &&journ->dtStart().date() >= mStartDate->date()) {
+                if (mDescriptionCheck->isChecked()) {
 #if QT_VERSION >= 0x030000
-                if (re.search(journ->description()) != -1) 
+                    if (re.search(journ->description()) != -1) 
 #else
-                    if (re.match(journ->description()) != -1) 
+                        if (re.match(journ->description()) != -1) 
 #endif
-                        {
-                            mMatchedJournals.append(journ);
-                            continue;
-                        }
+                            {
+                                if ( mSubItems->isChecked() )
+                                    mMatchedJournals.remove(journ);
+                                else if (!mMatchedJournals.contains( journ )) 
+                                    mMatchedJournals.append(journ);
+                                continue;
+                            }
+                }
+                if (mSummaryCheck->isChecked()) {
+#if QT_VERSION >= 0x030000
+                    if (re.search(journ->summary()) != -1) 
+#else
+                        if (re.match(journ->summary()) != -1) 
+#endif
+                            {
+                                if ( mSubItems->isChecked() )
+                                    mMatchedJournals.remove(journ);
+                                else if (!mMatchedJournals.contains( journ )) 
+                                    mMatchedJournals.append(journ);
+                                continue;
+                            }
+                }
             }
         }
     }
-
+    if ( mMatchedEvents.count() + mMatchedJournals.count() + mMatchedTodos.count()  < 1 ) {
+        qDebug("count %d ", mMatchedEvents.count() + mMatchedJournals.count() + mMatchedTodos.count() );
+        if ( mRefineItems->isChecked() )
+            mRefineItems->setChecked( false );
+        else if ( mSubItems->isChecked() )
+            mSubItems->setChecked( false );
+    }
 }
 
 void SearchDialog::keyPressEvent ( QKeyEvent *e) 
