@@ -110,9 +110,28 @@ void Calendar::init()
 Calendar::~Calendar()
 {
   delete mDefaultFilter;
-  if ( mUndoIncidence )
-      delete mUndoIncidence;
-}
+  clearUndo( 0 );
+} 
+void Calendar::clearUndo( Incidence * newUndo )
+{
+    
+    if ( mUndoIncidence ) {
+        if ( mUndoIncidence->typeID() == eventID )
+            delete  ((Event*) mUndoIncidence) ;
+        else if ( mUndoIncidence->typeID() == todoID )
+            delete ( (Todo*) mUndoIncidence );
+        else if ( mUndoIncidence->typeID() == journalID )
+            delete ( (Journal*) mUndoIncidence );
+        else 
+            delete mUndoIncidence;
+    }
+    mUndoIncidence =  newUndo;
+    if ( mUndoIncidence ) {
+        mUndoIncidence->clearRelations();
+    }
+    
+}   
+
 void Calendar::setDontDeleteIncidencesOnClose ()
 {
     mDeleteIncidencesOnClose = false;
@@ -447,7 +466,21 @@ void Calendar::removeRelations( Incidence *incidence )
         incidence->relatedTo()->removeRelation( incidence );
 
     // Remove this one from the orphans list
-    if( mOrphanUids.remove( uid ) )
+    if( mOrphanUids.remove( uid ) ) {
+        QString r2uid = incidence->relatedToUid();
+        QPtrList<Incidence> tempList;
+        while( Incidence* i = mOrphans[ r2uid ] ) {
+            mOrphans.remove( r2uid );
+            if ( i != incidence ) tempList.append( i );
+        }
+        Incidence* inc = tempList.first();
+        while ( inc ) {
+            mOrphans.insert( r2uid, inc );
+            inc = tempList.next();
+        }
+    }
+    // LR: and another big bad bug found
+#if 0
         // This incidence is located in the orphans list - it should be removed
         if( !( incidence->relatedTo() != 0 && mOrphans.remove( incidence->relatedTo()->uid() ) ) ) {
             // Removing wasn't that easy
@@ -458,6 +491,7 @@ void Calendar::removeRelations( Incidence *incidence )
                 }
             }
         }
+#endif
 }
 
 void Calendar::registerObserver( Observer *observer )
