@@ -514,13 +514,13 @@ icalproperty *ICalFormatImpl::writeAttachment(Attachment *att)
 {
 #if 0
    icalattachtype* attach = icalattachtype_new();
-  if (att->isURI())
+  if (att->isUri())
     icalattachtype_set_url(attach, att->uri().utf8().data());
   else
     icalattachtype_set_base64(attach, att->data(), 0);
 #endif
   icalattach *attach;
-  if (att->isURI())
+  if (att->isUri())
       attach = icalattach_new_from_url( att->uri().utf8().data());
   else
       attach = icalattach_new_from_data ( (unsigned char *)att->data(), 0, 0);
@@ -1002,7 +1002,7 @@ FreeBusy *ICalFormatImpl::readFreeBusy(icalcomponent *vfreebusy)
         period_end = readICalDateTime(icalperiod.end);
         freebusy->addPeriod(period_start, period_end);
         break;
-
+        
       default:
         kdDebug(5800) << "ICALFormat::readIncidence(): Unknown property: " << kind
                   << endl;
@@ -1944,7 +1944,8 @@ bool ICalFormatImpl::populate( Calendar *cal, icalcomponent *calendar)
   while (c) {
 //    kdDebug(5800) << "----Todo found" << endl;
     Todo *todo = readTodo(c);
-    if (!cal->todo(todo->uid())) cal->addTodo(todo);
+    if (!cal->todo(todo->uid())) 
+        cal->addTodo(todo);
     c = icalcomponent_get_next_component(calendar,ICAL_VTODO_COMPONENT);
   }
 
@@ -1953,7 +1954,8 @@ bool ICalFormatImpl::populate( Calendar *cal, icalcomponent *calendar)
   while (c) {
 //    kdDebug(5800) << "----Event found" << endl;
     Event *event = readEvent(c);
-    if (!cal->event(event->uid())) cal->addEvent(event);
+    if (!cal->event(event->uid())) 
+        cal->addEvent(event);
     c = icalcomponent_get_next_component(calendar,ICAL_VEVENT_COMPONENT);
   }
 
@@ -1962,7 +1964,8 @@ bool ICalFormatImpl::populate( Calendar *cal, icalcomponent *calendar)
   while (c) {
 //    kdDebug(5800) << "----Journal found" << endl;
     Journal *journal = readJournal(c);
-    if (!cal->journal(journal->uid())) cal->addJournal(journal);
+    if (!cal->journal(journal->uid()))
+        cal->addJournal(journal);
     c = icalcomponent_get_next_component(calendar,ICAL_VJOURNAL_COMPONENT);
   }
 
