@@ -342,6 +342,12 @@ void Incidence::setLastModifiedSubInvalid()
     if ( mRelatedTo )
         mRelatedTo->setLastModifiedSubInvalid();
 }
+QString Incidence::lastModifiedSubSortKey() const
+{
+    if ( mLastModifiedSubSortKey.isEmpty() )
+        return lastModifiedSortKey();
+    return mLastModifiedSubSortKey;
+}
 QDateTime Incidence::lastModifiedSub()
 {
     if ( !mRelations.count() )
@@ -355,6 +361,13 @@ QDateTime Incidence::lastModifiedSub()
         if ( inc->lastModifiedSub() > mLastModifiedSub )
             mLastModifiedSub = inc->lastModifiedSub();
     }
+    mLastModifiedSubSortKey.sprintf("%04d%02d%02d%02d%02d%02d",
+                                    mLastModifiedSub.date().year(),
+                                    mLastModifiedSub.date().month(),
+                                    mLastModifiedSub.date().day(),
+                                    mLastModifiedSub.time().hour(),
+                                    mLastModifiedSub.time().minute(),
+                                    mLastModifiedSub.time().second() );
     return mLastModifiedSub;
 }
 void Incidence::setCreated(QDateTime created)
