@@ -193,7 +193,7 @@ QString IncidenceBase::uid() const
 }
 void IncidenceBase::setLastModifiedSubInvalid()
 {
-
+    // virtual method
 }
 void IncidenceBase::setLastModified(const QDateTime &lm)
 {
@@ -201,9 +201,20 @@ void IncidenceBase::setLastModified(const QDateTime &lm)
   // DON'T! updated() because we call this from
   // Calendar::updateEvent().
   mLastModified = getEvenTime(lm);
+  mLastModifiedKey.sprintf("%04d%02d%02d%02d%02d%02d",
+                           mLastModified.date().year(),
+                           mLastModified.date().month(),
+                           mLastModified.date().day(),
+                           mLastModified.time().hour(),
+                           mLastModified.time().minute(),
+                           mLastModified.time().second() );
   setLastModifiedSubInvalid();
   //qDebug("IncidenceBase::setLastModified %s ",lm.toString().latin1());
 }
+QString IncidenceBase::lastModifiedSortKey() const
+{  
+    return mLastModifiedKey;
+}
 
 QDateTime IncidenceBase::lastModified() const
 {
