@@ -63,6 +63,7 @@ class IncidenceBase : public CustomProperties
     void setLastModified(const QDateTime &lm);
     /** Return the time the incidence was last modified. */
     QDateTime lastModified() const;
+    QString lastModifiedSortKey() const;
 
     /** sets the organizer for the event */
     void setOrganizer(const QString &o);
@@ -160,6 +161,7 @@ class IncidenceBase : public CustomProperties
   private:
     // base components
     QString mOrganizer;
+    QString mLastModifiedKey;
     QString mUid;
     int mCalID;
     bool mCalEnabled;
