@@ -53,7 +53,7 @@ public:
 
 static bool no_query_exit = false;
 
-KMainWindow::KMainWindow( QWidget* parent, const char *name, WFlags f )
+KMainWindow::KMainWindow( QWidget* parent, const char *name )
     : QMainWindow( parent, name ) /*LR, f ) with the default widget flag we cannot have fastload */ /*US, KXMLGUIBuilder( this ), helpMenu2( 0 ), factory_( 0 )*/
 {
     mQToolBar = 0;
@@ -847,10 +847,11 @@ QString KMainWindow::settingsGroup() const
     return d->autoSaveGroup;
 }
 
-void KMainWindow::resizeEvent( QResizeEvent * )
+void KMainWindow::resizeEvent( QResizeEvent * e)
 {
     if ( d->autoSaveWindowSize )
-        setSettingsDirty();
+        setSettingsDirty(); 
+    QMainWindow::resizeEvent( e ); 
 }
 
 bool KMainWindow::hasMenuBar()
@@ -940,9 +941,9 @@ void KMainWindow::childEvent( QChildEvent* e)
     QMainWindow::childEvent( e );
 }
 
-void KMainWindow::paintEvent( QPaintEvent * )
+void KMainWindow::paintEvent( QPaintEvent * e)
 {
-    // do nothing
+    QMainWindow::paintEvent( e );
 }
 
 QSize KMainWindow::sizeForCentralWidgetSize(QSize size)
