@@ -15,7 +15,7 @@
     the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
 
-    $Id: kmainwindow.h,v 1.2 2004/10/25 22:24:47 zautrix Exp $
+    $Id: kmainwindow.h,v 1.3 2005/08/23 20:09:30 zautrix Exp $
 
 */
 
@@ -94,7 +94,7 @@ public:
      *  <pre> KMainWindow *kmw = new KMainWindow (...</pre>
      **/
     //LR remove  WDestructiveClose
-    KMainWindow( QWidget* parent = 0, const char *name = 0, WFlags f = WType_TopLevel /*| WDestructiveClose*/ );
+    KMainWindow( QWidget* parent = 0, const char *name = 0 ); //, WFlags f = WType_TopLevel /*| WDestructiveClose*/ ;
 
 
     /**
