@@ -1415,13 +1415,13 @@ void KToolBar::repaintMe()
 {
     setUpdatesEnabled( true );
     QToolBar::repaint( true );
-    //qDebug(" KToolBar::repaintMe() ");
+    qDebug(" KToolBar::repaintMe() ");
 }
 
 void KToolBar::showEvent( QShowEvent *e )
 {
-    QToolBar::showEvent( e );
     rebuildLayout();
+    QToolBar::showEvent( e );
 }
 
 void KToolBar::setStretchableWidget( QWidget *w )
