@@ -14,7 +14,7 @@
  * This file is originaly based on version 1.0.1 of pwmanager
  * and was modified to run on embedded devices that run microkde
  *
- * $Id: pwm.cpp,v 1.29 2005/03/10 09:14:00 zautrix Exp $
+ * $Id: pwm.cpp,v 1.30 2005/06/10 11:53:37 zautrix Exp $
  **************************************************************************/  
 
 #include <klocale.h>
@@ -37,6 +37,7 @@
 #include <qmessagebox.h>
 #include <pwmprefs.h>
 #include <kpimglobalprefs.h>
+#include <kprefsdialog.h>
 #include <kcmconfigs/kcmpwmconfig.h>
 #include <kcmconfigs/kcmkdepimconfig.h>
 #include <kcmultidialog.h>
@@ -74,7 +75,6 @@
 # include "pwmkeycard.h"
 #endif
 
-
 #define DEFAULT_SIZE		(QSize(700, 400))
 
 // Button IDs for "file" popup menu
@@ -117,7 +117,8 @@ enum {
 };
 // Button IDs for "options" popup menu
 enum {
-	BUTTON_POPUP_OPTIONS_CONFIG = 0
+	BUTTON_POPUP_OPTIONS_CONFIG = 0,
+	BUTTON_POPUP_OPTIONS_GLOBAL_CONFIG
 #ifdef PWM_EMBEDDED
 	,BUTTON_POPUP_OPTIONS_CATEGORY
 #endif
@@ -359,9 +360,13 @@ void PwM::initMenubar()
 	menuBar()->insertItem(i18n("&View"), viewPopup);
 // "options" popup menu
 	optionsPopup->insertItem(QIconSet(picons->loadIcon("configure", KIcon::Small)),
-				 i18n("&Configure..."), this,
+				 i18n("&Configure PwM/Pi..."), this,
                  SLOT(config_slot()),0,
 				 BUTTON_POPUP_OPTIONS_CONFIG);
+	optionsPopup->insertItem(QIconSet(picons->loadIcon("configure", KIcon::Small)),
+				 i18n("Global Settings..."), this,
+                 SLOT(config_global_slot()),0,
+				 BUTTON_POPUP_OPTIONS_GLOBAL_CONFIG);
     if ( QApplication::desktop()->width() <= 240 ) {
         managePopup->insertSeparator();
         managePopup->insertItem(i18n("&Options"), optionsPopup);
@@ -851,11 +856,16 @@ void PwM::unlockWnd_slot()
 	PWM_ASSERT(curDoc());
 	curDoc()->lockAll(false);
 }
-
+void PwM::config_global_slot()
+{
+  KPimPrefsGlobalDialog gc ( this );
+    gc.exec();
+}
 void PwM::config_slot()
 {
   int oldStyle = conf()->confWndMainViewStyle();
-#ifdef PWM_EMBEDDED  
+
+#if 0 
     KCMultiDialog*  ConfigureDialog = new KCMultiDialog( "PIM", this ,"pwmconfigdialog", true );
 
     KCMPwmConfig* pwmcfg = new KCMPwmConfig( ConfigureDialog->getNewVBoxPage(i18n( "PwManager")) , "KCMPwmConfig" );
@@ -863,19 +873,34 @@ void PwM::config_slot()
 
     KCMKdePimConfig* kdelibcfg = new KCMKdePimConfig( ConfigureDialog->getNewVBoxPage(i18n( "Global")) , "KCMKdeLibConfig" );
     ConfigureDialog->addModule(kdelibcfg );
+#endif
 
+
+
+    KDialogBase * ConfigureDialog = new KDialogBase (  KDialogBase::Plain , i18n("Configure KA/Pi"), KDialogBase::Default |KDialogBase::Cancel | KDialogBase::Apply | KDialogBase::Ok, KDialogBase::Ok,0, "name", true, true);
+
+    KCMPwmConfig* kabcfg = new KCMPwmConfig( ConfigureDialog , "KCMpwmConfig" );
+    ConfigureDialog->setMainWidget( kabcfg );
+    connect( ConfigureDialog, SIGNAL( applyClicked() ),
+            kabcfg, SLOT( save() ) );
+    connect( ConfigureDialog, SIGNAL( acceptClicked() ),
+             kabcfg, SLOT( save() ) );
+    connect( ConfigureDialog, SIGNAL( defaultClicked() ),
+             kabcfg, SLOT( defaults() ) );
+    //saveSettings();
+    kabcfg->load();
 #ifndef DESKTOP_VERSION
+    if ( QApplication::desktop()->height() <= 480 )
+        ;// ConfigureDialog->hideButtons(); 
     ConfigureDialog->showMaximized();
 #endif
+
+
     if ( ConfigureDialog->exec() )
         KMessageBox::information( this,  i18n("Some changes are only\neffective after a restart!\n") );
     delete ConfigureDialog;
 
-#else //PWM_EMBEDDED
-	// display the configuration window (modal mode)
-	if (!conf()->showConfWnd(this))
-		return;
-#endif
+
 
 	int newStyle = conf()->confWndMainViewStyle();
 	// reinitialize tray
