@@ -14,7 +14,7 @@
  * This file is originaly based on version 1.1 of pwmanager
  * and was modified to run on embedded devices that run microkde
  *
- * $Id: pwmdoc.cpp,v 1.30 2005/04/21 22:08:02 zautrix Exp $
+ * $Id: pwmdoc.cpp,v 1.31 2005/06/24 23:41:53 zautrix Exp $
  **************************************************************************/  
 
 #include "pwmdoc.h"
@@ -436,7 +436,7 @@ PwMerror PwMDoc::saveDoc(char compress, const QString *file)
       KConfig config (locateLocal("config","microkdeglobalrc"));
       config.setGroup( "BackupSettings" );
       bool b_enabled =   config.readBoolEntry( "BackupEnabled" );
-      if ( b_enabled ) {
+      if ( b_enabled && QFile::exists(filename)) {
           int num = config.readNumEntry( "BackupNumbers" );
           int d_count = config.readNumEntry( "BackupDayCount" );
           bool stdDir = config.readBoolEntry( "BackupUseDefaultDir" );
